@@ -1,30 +1,34 @@
 // File_Aac - Info for AAC files
-// Copyright (C) 2007-2011 MediaArea.net SARL, Info@MediaArea.net
+// Copyright (C) 2007-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // any later version.
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this library. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
 //---------------------------------------------------------------------------
-// Compilation conditions
-#include "MediaInfo/Setup.h"
+// Pre-compilation
+#include "MediaInfo/PreComp.h"
 #ifdef __BORLANDC__
     #pragma hdrstop
 #endif
 //---------------------------------------------------------------------------
 
+//---------------------------------------------------------------------------
+#include "MediaInfo/Setup.h"
+//---------------------------------------------------------------------------
+
 //---------------------------------------------------------------------------
 #if defined(MEDIAINFO_AAC_YES)
 //---------------------------------------------------------------------------
@@ -245,9 +249,9 @@ void File_Aac::AudioSpecificConfig (size_t End)
 {
     //Parsing
     bool    sbrData=false, sbrPresentFlag=false, psData=false, psPresentFlag=false;
-    Element_Begin("AudioSpecificConfig");
+    Element_Begin1("AudioSpecificConfig");
     GetAudioObjectType(audioObjectType,                         "audioObjectType");
-    Get_S1 (4, sampling_frequency_index,                        "samplingFrequencyIndex"); Param_Info(Aac_sampling_frequency[sampling_frequency_index]);
+    Get_S1 (4, sampling_frequency_index,                        "samplingFrequencyIndex"); Param_Info1(Aac_sampling_frequency[sampling_frequency_index]);
     if (sampling_frequency_index==0xF)
     {
         Get_S3 (24, sampling_frequency,                         "samplingFrequency");
@@ -255,14 +259,14 @@ void File_Aac::AudioSpecificConfig (size_t End)
     }
     else
         sampling_frequency=Aac_sampling_frequency[sampling_frequency_index];
-    Get_S1 (4, channelConfiguration,                            "channelConfiguration"); Param_Info(Aac_ChannelConfiguration[channelConfiguration]);
+    Get_S1 (4, channelConfiguration,                            "channelConfiguration"); Param_Info1(Aac_ChannelConfiguration[channelConfiguration]);
     if (audioObjectType==0x05 || audioObjectType==0x29)
     {
         extensionAudioObjectType=5;
         sbrPresentFlag=true;
         if (audioObjectType==29)
             psPresentFlag=true;
-        Get_S1 (4, extension_sampling_frequency_index,          "extensionSamplingFrequencyIndex"); Param_Info(Aac_sampling_frequency[extension_sampling_frequency_index]);
+        Get_S1 (4, extension_sampling_frequency_index,          "extensionSamplingFrequencyIndex"); Param_Info1(Aac_sampling_frequency[extension_sampling_frequency_index]);
         if (extension_sampling_frequency_index==0xF)
         {
             Get_S3 (24, extension_sampling_frequency,           "extensionSamplingFrequency");
@@ -349,9 +353,9 @@ void File_Aac::AudioSpecificConfig (size_t End)
             //~ SymbolicMusicSpecificConfig(); //ISO/IEC 14496-23
             //~ break;
         default:
-            Element_Begin("not implemented part");
+            Element_Begin1("not implemented part");
             Skip_BS(Data_BS_Remain()-End,                       "(Not implemented)");
-            Element_End();
+            Element_End0();
             if (Mode==File_Aac::Mode_ADIF || Mode==File_Aac::Mode_ADTS)
                 File__Tags_Helper::Finish();
             else
@@ -383,9 +387,9 @@ void File_Aac::AudioSpecificConfig (size_t End)
                 Get_SB(directMapping,                           "directMapping");
                 if ( ! directMapping )
                 {
-                    Element_Begin("not implemented part");
+                    Element_Begin1("not implemented part");
                     Skip_BS(Data_BS_Remain()-End,               "(Not implemented)");
-                    Element_End();
+                    Element_End0();
                     if (Mode==File_Aac::Mode_ADIF || Mode==File_Aac::Mode_ADTS)
                         File__Tags_Helper::Finish();
                     else
@@ -410,7 +414,7 @@ void File_Aac::AudioSpecificConfig (size_t End)
                 Get_SB(sbrPresentFlag,                          "sbrPresentFlag");
                 if (sbrPresentFlag)
                 {
-                    Get_S1 (4, extension_sampling_frequency_index, "extensionSamplingFrequencyIndex"); Param_Info(Aac_sampling_frequency[extension_sampling_frequency_index]);
+                    Get_S1 (4, extension_sampling_frequency_index, "extensionSamplingFrequencyIndex"); Param_Info1(Aac_sampling_frequency[extension_sampling_frequency_index]);
                     if (extension_sampling_frequency_index==0xF)
                     {
                         Get_S3 (24, extension_sampling_frequency, "extensionSamplingFrequency");
@@ -435,7 +439,7 @@ void File_Aac::AudioSpecificConfig (size_t End)
                 Get_SB(sbrPresentFlag,                          "sbrPresentFlag");
                 if (sbrPresentFlag)
                 {
-                    Get_S1 (4, extension_sampling_frequency_index, "extensionSamplingFrequencyIndex"); Param_Info(Aac_sampling_frequency[extension_sampling_frequency_index]);
+                    Get_S1 (4, extension_sampling_frequency_index, "extensionSamplingFrequencyIndex"); Param_Info1(Aac_sampling_frequency[extension_sampling_frequency_index]);
                     if (extension_sampling_frequency_index==0xF)
                     {
                         Get_S3 (24, extension_sampling_frequency, "extensionSamplingFrequency");
@@ -448,12 +452,12 @@ void File_Aac::AudioSpecificConfig (size_t End)
             }
         }
     }
-    Element_End();
+    Element_End0();
     if (Data_BS_Remain()>End)
     {
         int8u LastByte=0xFF;
         if (Data_BS_Remain()-End<8)
-            Peek_S1(Data_BS_Remain()-End, LastByte);
+            Peek_S1((int8u)(Data_BS_Remain()-End), LastByte);
         Skip_BS(Data_BS_Remain()-End,                           LastByte?"Unknown":"Padding");
     }
 
@@ -485,7 +489,7 @@ void File_Aac::AudioSpecificConfig_OutOfBand (int32u sampling_frequency_, int8u
         if (Infos.find("Format_Settings_SBR")!=Infos.end())
         {
             sbrData=true;
-            sbrPresentFlag=Infos["Format_Settings_SBR"].find(_T("Yes"))!=string::npos;
+            sbrPresentFlag=Infos["Format_Settings_SBR"].find(__T("Yes"))!=string::npos;
         }
         else
         {
@@ -495,7 +499,7 @@ void File_Aac::AudioSpecificConfig_OutOfBand (int32u sampling_frequency_, int8u
         if (Infos.find("Format_Settings_PS")!=Infos.end())
         {
             psData=true;
-            psPresentFlag=Infos["Format_Settings_PS"].find(_T("Yes"))!=string::npos;
+            psPresentFlag=Infos["Format_Settings_PS"].find(__T("Yes"))!=string::npos;
         }
         else
         {
@@ -519,58 +523,58 @@ void File_Aac::AudioSpecificConfig_OutOfBand (int32u sampling_frequency_, int8u
 
     if (sbrPresentFlag)
     {
-        Infos["Format_Profile"]=_T("HE-AAC");
+        Infos["Format_Profile"]=__T("HE-AAC");
         Ztring SamplingRate=Infos["SamplingRate"];
         Infos["SamplingRate"].From_Number((extension_sampling_frequency_index==(int8u)-1)?(sampling_frequency*2):extension_sampling_frequency, 10);
         if (MediaInfoLib::Config.LegacyStreamDisplay_Get())
         {
-            Infos["Format_Profile"]+=_T(" / LC");
-            Infos["SamplingRate"]+=_T(" / ")+SamplingRate;
+            Infos["Format_Profile"]+=__T(" / LC");
+            Infos["SamplingRate"]+=__T(" / ")+SamplingRate;
         }
-        Infos["Format_Settings_SBR"]=_T("Yes (Implicit)");
-        Infos["Codec"]=Ztring().From_Local(Aac_audioObjectType(audioObjectType))+_T("-SBR");
+        Infos["Format_Settings_SBR"]=__T("Yes (Implicit)");
+        Infos["Codec"]=Ztring().From_Local(Aac_audioObjectType(audioObjectType))+__T("-SBR");
     }
     else if (sbrData)
-        Infos["Format_Settings_SBR"]=_T("No (Explicit)");
+        Infos["Format_Settings_SBR"]=__T("No (Explicit)");
 
     if (psPresentFlag)
     {
-        Infos["Format_Profile"]=_T("HE-AACv2");
+        Infos["Format_Profile"]=__T("HE-AACv2");
         Ztring Channels=Infos["Channel(s)"];
         Ztring ChannelPositions=Infos["ChannelPositions"];
         Ztring SamplingRate=Infos["SamplingRate"];
-        Infos["Channel(s)"]=_T("2");
-        Infos["ChannelPositions"]=_T("Front: L R");
+        Infos["Channel(s)"]=__T("2");
+        Infos["ChannelPositions"]=__T("Front: L R");
         if (MediaInfoLib::Config.LegacyStreamDisplay_Get())
         {
-            Infos["Format_Profile"]+=_T(" / HE-AAC / LC");
-            Infos["Channel(s)"]+=_T(" / ")+Channels+_T(" / ")+Channels;
-            Infos["ChannelPositions"]+=_T(" / ")+ChannelPositions+_T(" / ")+ChannelPositions;
-            Infos["SamplingRate"]=Ztring().From_Number((extension_sampling_frequency_index==(int8u)-1)?(sampling_frequency*2):extension_sampling_frequency, 10)+_T(" / ")+SamplingRate;
+            Infos["Format_Profile"]+=__T(" / HE-AAC / LC");
+            Infos["Channel(s)"]+=__T(" / ")+Channels+__T(" / ")+Channels;
+            Infos["ChannelPositions"]+=__T(" / ")+ChannelPositions+__T(" / ")+ChannelPositions;
+            Infos["SamplingRate"]=Ztring().From_Number((extension_sampling_frequency_index==(int8u)-1)?(sampling_frequency*2):extension_sampling_frequency, 10)+__T(" / ")+SamplingRate;
         }
-        Infos["Format_Settings_PS"]=_T("Yes (Implicit)");
+        Infos["Format_Settings_PS"]=__T("Yes (Implicit)");
         if (StreamPos_Last!=(size_t)-1)
         {
             Ztring Codec=Retrieve(Stream_Audio, StreamPos_Last, Audio_Codec);
-            Infos["Codec"]=Ztring().From_Local(Aac_audioObjectType(audioObjectType))+_T("-SBR-PS");
+            Infos["Codec"]=Ztring().From_Local(Aac_audioObjectType(audioObjectType))+__T("-SBR-PS");
         }
     }
     else if (psData)
-        Infos["Format_Settings_PS"]=_T("No (Explicit)");
+        Infos["Format_Settings_PS"]=__T("No (Explicit)");
 }
 
 //---------------------------------------------------------------------------
 void File_Aac::GetAudioObjectType(int8u &ObjectType, const char* Name)
 {
-    Element_Begin(Name);
+    Element_Begin1(Name);
     Get_S1(5, ObjectType,                                       "audioObjectType");
     if (ObjectType==31)
     {
         Get_S1(6, ObjectType,                                   "audioObjectTypeExt");
         ObjectType+=32;
     }
-    Element_Info(ObjectType); Element_Info(Aac_Format_Profile(ObjectType));
-    Element_End();
+    Element_Info1(ObjectType); Element_Info1(Aac_Format_Profile(ObjectType));
+    Element_End0();
 }
 
 //***************************************************************************
@@ -580,7 +584,7 @@ void File_Aac::GetAudioObjectType(int8u &ObjectType, const char* Name)
 //---------------------------------------------------------------------------
 void File_Aac::AudioMuxElement()
 {
-    Element_Begin("AudioMuxElement");
+    Element_Begin1("AudioMuxElement");
     if (muxConfigPresent)
     {
         bool useSameStreamMux;
@@ -608,19 +612,19 @@ void File_Aac::AudioMuxElement()
     }
     else
     {
-        Element_Begin("(not implemented)");
+        Element_Begin1("(not implemented)");
         Skip_BS(Data_BS_Remain(),                               "(not implemented)");
-        Element_End();
+        Element_End0();
     }
     if (Data_BS_Remain()%8)
         Skip_S1(Data_BS_Remain()%8,                             "byte_alignment");
-    Element_End();
+    Element_End0();
 }
 
 //---------------------------------------------------------------------------
 void File_Aac::StreamMuxConfig()
 {
-    Element_Begin("StreamMuxConfig");
+    Element_Begin1("StreamMuxConfig");
 
     bool useSameConfig,audioMuxVersion;
     Get_SB (audioMuxVersion,                                    "audioMuxVersion");
@@ -633,18 +637,18 @@ void File_Aac::StreamMuxConfig()
     {
         if (audioMuxVersion==1)
         {
-            Element_Begin("(not implemented)");
+            Element_Begin1("(not implemented)");
             Skip_BS(Data_BS_Remain(),                               "(not implemented)");
-            Element_End();
+            Element_End0();
             //taraBufferFullness=LatmGetValue();
         }
-        
+
         int8u streamCnt = 0;
 
         Get_SB (allStreamsSameTimeFraming,                      "allStreamsSameTimeFraming");
         Get_S1 (6, numSubFrames,                                "numSubFrames");
         Get_S1 (4, numProgram,                                  "numProgram");
-        
+
         for (int8u prog=0; prog<=numProgram; prog++)
         {
             Get_S1(3,numLayer,                                  "numLayer");
@@ -657,7 +661,7 @@ void File_Aac::StreamMuxConfig()
                     useSameConfig=0;
                 else
                     Get_SB(useSameConfig,                       "useSameConfig");
-                    
+
                 if (!useSameConfig)
                 {
                     if (audioMuxVersion==0)
@@ -676,9 +680,9 @@ void File_Aac::StreamMuxConfig()
                             Skip_S1(8,                          "latmBufferFullness[streamID[prog][lay]]");
                             if(!allStreamsSameTimeFraming)
                             {
-                                Element_Begin("(not implemented)");
+                                Element_Begin1("(not implemented)");
                                 Skip_BS(Data_BS_Remain(),       "(not implemented)");
-                                Element_End();
+                                Element_End0();
                             }
                             //~ if ((!allStreamsSameTimeFraming) &&
                             //~ (AudioObjectType[lay] == 6 || AudioObjectType[lay] == 20) &&
@@ -700,9 +704,9 @@ void File_Aac::StreamMuxConfig()
                             Skip_S1(1,                          "HVXCframeLengthTableIndex[streamID[prog][lay]]");
                             break;
                     default :
-                            Element_Begin("(not implemented)");
+                            Element_Begin1("(not implemented)");
                             Skip_BS(Data_BS_Remain(),       "(not implemented)");
-                            Element_End();
+                            Element_End0();
                 }
             }
         }
@@ -732,11 +736,11 @@ void File_Aac::StreamMuxConfig()
     }
     else
     {
-        Element_Begin("(not implemented)");
+        Element_Begin1("(not implemented)");
         Skip_BS(Data_BS_Remain(),                               "(not implemented)");
-        Element_End();
+        Element_End0();
     }
-    Element_End();
+    Element_End0();
 
     FILLING_BEGIN();
         CanFill=true;
@@ -746,7 +750,7 @@ void File_Aac::StreamMuxConfig()
 //---------------------------------------------------------------------------
 int32u File_Aac::LatmGetValue()
 {
-    Element_Begin("LatmGetValue");
+    Element_Begin1("LatmGetValue");
     int8u valueTmp, bytesForValue;
     Get_S1(2, bytesForValue,                                    "bytesForValue");
     int32u value=0;
@@ -756,14 +760,14 @@ int32u File_Aac::LatmGetValue()
         Get_S1(8, valueTmp,                                     "valueTmp");
         value+=valueTmp;
     }
-    Element_End();
+    Element_End0();
     return value;
 }
 
 //---------------------------------------------------------------------------
 void File_Aac::PayloadLengthInfo()
 {
-    Element_Begin("PayloadLengthInfo");
+    Element_Begin1("PayloadLengthInfo");
     int8u tmp;
     if (allStreamsSameTimeFraming)
     {
@@ -819,13 +823,13 @@ void File_Aac::PayloadLengthInfo()
             }
         }
     }
-    Element_End();
+    Element_End0();
 }
 
 //---------------------------------------------------------------------------
 void File_Aac::PayloadMux()
 {
-    Element_Begin("PayloadMux");
+    Element_Begin1("PayloadMux");
     if (allStreamsSameTimeFraming)
     {
         for (int8u prog=0; prog<=numProgram; prog++)
@@ -834,15 +838,22 @@ void File_Aac::PayloadMux()
                 switch(frameLengthType[streamID[prog][lay]])
                 {
                     case 0 :
-                            raw_data_block(); //Skip_BS(8*MuxSlotLengthBytes[streamID[prog][lay]],"payload[streamID[prog][lay]]");
+                            if (CA_system_ID_MustSkipSlices)
+                            {
+                                //Encryption management
+                                Skip_BS(8*MuxSlotLengthBytes[streamID[prog][lay]], "Encrypted payload[streamID[prog][lay]]");
+                                Frame_Count_Valid=0;
+                            }
+                            else
+                                raw_data_block();
                             break;
                     case 1 :
                             Skip_BS(8 * (frameLength[streamID[prog][lay]] + 20),"payload[streamID[prog][lay]]");
                             break;
                     default:
-                            Element_Begin("(not implemented)");
+                            Element_Begin1("(not implemented)");
                             Skip_BS(Data_BS_Remain(),           "(not implemented)");
-                            Element_End();
+                            Element_End0();
                 }
             }
     }
@@ -861,12 +872,12 @@ void File_Aac::PayloadMux()
                         Skip_BS(8*(frameLength[streamID[prog][lay]]+20), "payload[streamID[prog][lay]]");
                         break;
                 default:
-                        Element_Begin("not implemented");
-                        Element_End();
+                        Element_Begin1("not implemented");
+                        Element_End0();
             }
         }
     }
-    Element_End();
+    Element_End0();
 }
 
 //***************************************************************************
@@ -876,7 +887,7 @@ void File_Aac::PayloadMux()
 //---------------------------------------------------------------------------
 void File_Aac::ErrorProtectionSpecificConfig()
 {
-    Element_Begin("ErrorProtectionSpecificConfig");
+    Element_Begin1("ErrorProtectionSpecificConfig");
     int8u number_of_predefined_set,number_of_concatenated_frame,interleave_type;
     Get_S1(8,number_of_predefined_set,                          "number_of_predefined_set");
     Get_S1(2,interleave_type,                                   "interleave_type");
@@ -886,7 +897,7 @@ void File_Aac::ErrorProtectionSpecificConfig()
     {
         int8u number_of_class;
         Get_S1(6,number_of_class,                               "number_of_class[i]");
-        for (int8u j = 0; j < number_of_class; j++) 
+        for (int8u j = 0; j < number_of_class; j++)
         {
             bool length_escape,fec_type,rate_escape,crclen_escape;
             Get_SB(length_escape,                               "length_escape[i][j]");
@@ -895,21 +906,21 @@ void File_Aac::ErrorProtectionSpecificConfig()
             if (number_of_concatenated_frame != 1)
                 Skip_SB(                                        "concatenate_flag[i][j]");
             Get_SB(fec_type,                                    "fec_type[i][j]");
-            if(!fec_type) 
+            if(!fec_type)
                 Skip_SB(                                        "termination_switch[i][j]");
-            if (interleave_type == 2) 
+            if (interleave_type == 2)
                 Skip_S1(2,                                      "interleave_switch[i][j]");
             Skip_SB(                                            "class_optional");
-            if (length_escape) 
+            if (length_escape)
             {
                 /* ESC */
                 Skip_S1(4,                                      "number_of_bits_for_length[i][j]");
             }
-            else 
+            else
             {
                 Skip_S2(16,                                     "class_length[i][j]");
             }
-            if (!rate_escape) 
+            if (!rate_escape)
             { /* not ESC */
                 if(fec_type)
                 {
@@ -920,7 +931,7 @@ void File_Aac::ErrorProtectionSpecificConfig()
                     Skip_S1(5,                                  "class_rate[i][j]");
                 }
             }
-            if (!crclen_escape) 
+            if (!crclen_escape)
             {
             /* not ESC */
             Skip_S1(5,                                          "class_crclen[i][j]");
@@ -928,9 +939,9 @@ void File_Aac::ErrorProtectionSpecificConfig()
         }
         bool class_reordered_output;
         Get_SB(class_reordered_output,                          "class_reordered_output");
-        if ( class_reordered_output ) 
+        if ( class_reordered_output )
         {
-            for (int j = 0; j < number_of_class; j++ ) 
+            for (int j = 0; j < number_of_class; j++ )
             {
                 Skip_S1(6,                                      "class_output_order[i][j]");
             }
@@ -938,12 +949,12 @@ void File_Aac::ErrorProtectionSpecificConfig()
     }
     bool header_protection;
     Get_SB(header_protection,                                   "header_protection");
-    if (header_protection) 
+    if (header_protection)
     {
         Skip_S1(5,                                              "header_rate");
         Skip_S1(5,                                              "header_crclen");
     }
-    Element_End();
+    Element_End0();
 }
 
 //***************************************************************************
@@ -966,7 +977,7 @@ void File_Aac::adif_header()
     TEST_SB_END();
     Skip_SB(                                                    "original_copy");
     Skip_SB(                                                    "home");
-    Get_SB (    bitstream_type,                                 "bitstream_type"); Param_Info(bitstream_type?"VBR":"CBR");
+    Get_SB (    bitstream_type,                                 "bitstream_type"); Param_Info1(bitstream_type?"VBR":"CBR");
     Get_S3 (23, bitrate,                                        "bitrate");
     Get_S1 ( 4, num_program_config_elements,                    "num_program_config_elements");
     if (!bitstream_type)
@@ -977,6 +988,7 @@ void File_Aac::adif_header()
 
     FILLING_BEGIN();
         Fill(Stream_General, 0, General_Format, "ADIF", Unlimited, true, true);
+        Fill(Stream_General, 0, General_HeaderSize, Element_Size);
         Fill(Stream_General, 0, General_OverallBitRate_Mode, bitstream_type?"VBR":"CBR");
 
         for (size_t StreamPos=0; StreamPos<Count_Get(Stream_Audio); StreamPos++)
@@ -1003,33 +1015,44 @@ void File_Aac::adts_frame()
     //Parsing
     adts_fixed_header();
     adts_variable_header();
+
+    //Encryption management
+    if (CA_system_ID_MustSkipSlices)
+    {
+        //Is not decodable
+        BS_End();
+        Skip_XX(Element_Size-Element_Offset,                    "Encrypted data");
+        Frame_Count_Valid=0;
+        return;
+    }
+
     if (num_raw_data_blocks==0)
     {
         if (!protection_absent)
         {
-            Element_Begin("adts_error_check");
+            Element_Begin1("adts_error_check");
                 Skip_S2(16,                                     "crc_check");
-            Element_End();
+            Element_End0();
         }
         raw_data_block();
     }
     else
     {
-        Element_Begin("adts_header_error_check");
+        Element_Begin1("adts_header_error_check");
             if (!protection_absent)
                 for (int i=1; i<=num_raw_data_blocks; i++)
                     Skip_S2(16,                                 "raw_data_block_position(i)");
             Skip_S2(16,                                         "crc_check");
-        Element_End();
+        Element_End0();
 
         for(int i=0; i<=num_raw_data_blocks; i++)
         {
             raw_data_block();
             if (!protection_absent)
             {
-                Element_Begin("adts_raw_data_block_error_check");
+                Element_Begin1("adts_raw_data_block_error_check");
                     Skip_BS(16,                                 "crc_check");
-                Element_End();
+                Element_End0();
             }
         }
     }
@@ -1040,19 +1063,19 @@ void File_Aac::adts_fixed_header()
 {
     //Parsing
     bool    id;
-    Element_Begin("adts_fixed_header");
+    Element_Begin1("adts_fixed_header");
     Skip_BS(12,                                                 "syncword");
-    Get_SB (    id,                                             "id"); Param_Info(Aac_Adts_ID[id]);
+    Get_SB (    id,                                             "id"); Param_Info1(Aac_Adts_ID[id]);
     Skip_BS( 2,                                                 "layer");
     Get_SB (    protection_absent,                              "protection_absent");
-    Get_S1 ( 2, audioObjectType,                                "profile_ObjectType"); audioObjectType++; Param_Info(Aac_audioObjectType(audioObjectType));
-    Get_S1 ( 4, sampling_frequency_index,                       "sampling_frequency_index"); Param_Info(Aac_sampling_frequency[sampling_frequency_index], " Hz");
+    Get_S1 ( 2, audioObjectType,                                "profile_ObjectType"); audioObjectType++; Param_Info1(Aac_audioObjectType(audioObjectType));
+    Get_S1 ( 4, sampling_frequency_index,                       "sampling_frequency_index"); Param_Info2(Aac_sampling_frequency[sampling_frequency_index], " Hz");
     sampling_frequency=Aac_sampling_frequency[sampling_frequency_index];
     Skip_SB(                                                    "private");
     Get_S1 ( 3, channelConfiguration,                           "channel_configuration");
     Skip_SB(                                                    "original");
     Skip_SB(                                                    "home");
-    Element_End();
+    Element_End0();
 
     FILLING_BEGIN();
         if (Infos["Format"].empty())
@@ -1078,13 +1101,13 @@ void File_Aac::adts_variable_header()
 {
     //Parsing
     int16u  aac_frame_length, adts_buffer_fullness;
-    Element_Begin("adts_variable_header");
+    Element_Begin1("adts_variable_header");
     Skip_SB(                                                    "copyright_id");
     Skip_SB(                                                    "copyright_id_start");
     Get_S2 (13, aac_frame_length,                               "aac_frame_length");
-    Get_S2 (11, adts_buffer_fullness,                           "adts_buffer_fullness"); Param_Info(adts_buffer_fullness==0x7FF?"VBR":"CBR");
+    Get_S2 (11, adts_buffer_fullness,                           "adts_buffer_fullness"); Param_Info1(adts_buffer_fullness==0x7FF?"VBR":"CBR");
     Get_S1 ( 2, num_raw_data_blocks,                            "num_raw_data_blocks");
-    Element_End();
+    Element_End0();
 
     FILLING_BEGIN();
         aac_frame_lengths.push_back(aac_frame_length);
