@@ -1,19 +1,18 @@
 // Enums - Automaticly generated enums for MediaInfo
-// Copyright (C) 2008-2008 Jerome Martinez, Zen@MediaArea.net
+// Copyright (C) 2008-2012 MediaArea.net SARL, Info@MediaArea.net
 //
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public
-// License as published by the Free Software Foundation; either
-// version 2.1 of the License, or (at your option) any later version.
+// This library is free software: you can redistribute it and/or modify it
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
+// any later version.
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Lesser General Public License for more details.
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public
-// License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// You should have received a copy of the GNU Library General Public License
+// along with this library. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -38,9 +37,13 @@ enum generic
     Generic_Format,
     Generic_Format_Info,
     Generic_Format_Url,
+    Generic_Format_Commercial,
+    Generic_Format_Commercial_IfAny,
     Generic_Format_Version,
     Generic_Format_Profile,
+    Generic_Format_Compression,
     Generic_Format_Settings,
+    Generic_InternetMediaType,
     Generic_CodecID,
     Generic_CodecID_Info,
     Generic_CodecID_Hint,
@@ -56,6 +59,11 @@ enum generic
     Generic_Duration_String1,
     Generic_Duration_String2,
     Generic_Duration_String3,
+    Generic_Source_Duration,
+    Generic_Source_Duration_String,
+    Generic_Source_Duration_String1,
+    Generic_Source_Duration_String2,
+    Generic_Source_Duration_String3,
     Generic_BitRate_Mode,
     Generic_BitRate_Mode_String,
     Generic_BitRate,
@@ -66,6 +74,42 @@ enum generic
     Generic_BitRate_Nominal_String,
     Generic_BitRate_Maximum,
     Generic_BitRate_Maximum_String,
+    Generic_BitRate_Encoded,
+    Generic_BitRate_Encoded_String,
+    Generic_FrameCount,
+    Generic_Source_FrameCount,
+    Generic_ColorSpace,
+    Generic_ChromaSubsampling,
+    Generic_Resolution,
+    Generic_Resolution_String,
+    Generic_BitDepth,
+    Generic_BitDepth_String,
+    Generic_Compression_Mode,
+    Generic_Compression_Mode_String,
+    Generic_Compression_Ratio,
+    Generic_Delay,
+    Generic_Delay_String,
+    Generic_Delay_String1,
+    Generic_Delay_String2,
+    Generic_Delay_String3,
+    Generic_Delay_String4,
+    Generic_Delay_Settings,
+    Generic_Delay_Source,
+    Generic_Delay_Source_String,
+    Generic_Delay_Original,
+    Generic_Delay_Original_String,
+    Generic_Delay_Original_String1,
+    Generic_Delay_Original_String2,
+    Generic_Delay_Original_String3,
+    Generic_Delay_Original_String4,
+    Generic_Delay_Original_Settings,
+    Generic_Delay_Original_Source,
+    Generic_Video_Delay,
+    Generic_Video_Delay_String,
+    Generic_Video_Delay_String1,
+    Generic_Video_Delay_String2,
+    Generic_Video_Delay_String3,
+    Generic_Video_Delay_String4,
     Generic_StreamSize,
     Generic_StreamSize_String,
     Generic_StreamSize_String1,
@@ -74,21 +118,51 @@ enum generic
     Generic_StreamSize_String4,
     Generic_StreamSize_String5,
     Generic_StreamSize_Proportion,
+    Generic_Source_StreamSize,
+    Generic_Source_StreamSize_String,
+    Generic_Source_StreamSize_String1,
+    Generic_Source_StreamSize_String2,
+    Generic_Source_StreamSize_String3,
+    Generic_Source_StreamSize_String4,
+    Generic_Source_StreamSize_String5,
+    Generic_Source_StreamSize_Proportion,
+    Generic_StreamSize_Encoded,
+    Generic_StreamSize_Encoded_String,
+    Generic_StreamSize_Encoded_String1,
+    Generic_StreamSize_Encoded_String2,
+    Generic_StreamSize_Encoded_String3,
+    Generic_StreamSize_Encoded_String4,
+    Generic_StreamSize_Encoded_String5,
+    Generic_StreamSize_Encoded_Proportion,
+    Generic_Source_StreamSize_Encoded,
+    Generic_Source_StreamSize_Encoded_String,
+    Generic_Source_StreamSize_Encoded_String1,
+    Generic_Source_StreamSize_Encoded_String2,
+    Generic_Source_StreamSize_Encoded_String3,
+    Generic_Source_StreamSize_Encoded_String4,
+    Generic_Source_StreamSize_Encoded_String5,
+    Generic_Source_StreamSize_Encoded_Proportion,
+    Generic_Language,
+    Generic_ServiceName,
+    Generic_ServiceProvider,
 };
 
 //---------------------------------------------------------------------------
 enum general
 {
     General_Count,
+    General_Status,
     General_StreamCount,
     General_StreamKind,
     General_StreamKind_String,
     General_StreamKindID,
     General_StreamKindPos,
+    General_StreamOrder,
     General_Inform,
     General_ID,
     General_ID_String,
     General_UniqueID,
+    General_UniqueID_String,
     General_MenuID,
     General_MenuID_String,
     General_GeneralCount,
@@ -131,10 +205,15 @@ enum general
     General_Format_Info,
     General_Format_Url,
     General_Format_Extensions,
+    General_Format_Commercial,
+    General_Format_Commercial_IfAny,
     General_Format_Version,
     General_Format_Profile,
+    General_Format_Compression,
     General_Format_Settings,
+    General_InternetMediaType,
     General_CodecID,
+    General_CodecID_String,
     General_CodecID_Info,
     General_CodecID_Hint,
     General_CodecID_Url,
@@ -170,6 +249,11 @@ enum general
     General_OverallBitRate_Nominal_String,
     General_OverallBitRate_Maximum,
     General_OverallBitRate_Maximum_String,
+    General_Delay,
+    General_Delay_String,
+    General_Delay_String1,
+    General_Delay_String2,
+    General_Delay_String3,
     General_StreamSize,
     General_StreamSize_String,
     General_StreamSize_String1,
@@ -181,6 +265,7 @@ enum general
     General_HeaderSize,
     General_DataSize,
     General_FooterSize,
+    General_IsStreamable,
     General_Album_ReplayGain_Gain,
     General_Album_ReplayGain_Gain_String,
     General_Album_ReplayGain_Peak,
@@ -200,6 +285,9 @@ enum general
     General_Album,
     General_Album_More,
     General_Album_Sort,
+    General_Album_Performer,
+    General_Album_Performer_Sort,
+    General_Album_Performer_Url,
     General_Comic,
     General_Comic_More,
     General_Comic_Position_Total,
@@ -212,12 +300,15 @@ enum general
     General_Track_Sort,
     General_Track_Position,
     General_Track_Position_Total,
+    General_Grouping,
     General_Chapter,
     General_SubTrack,
     General_Original_Album,
     General_Original_Movie,
     General_Original_Part,
     General_Original_Track,
+    General_Compilation,
+    General_Compilation_String,
     General_Performer,
     General_Performer_Sort,
     General_Performer_Url,
@@ -344,22 +435,31 @@ enum general
 enum video
 {
     Video_Count,
+    Video_Status,
     Video_StreamCount,
     Video_StreamKind,
     Video_StreamKind_String,
     Video_StreamKindID,
     Video_StreamKindPos,
+    Video_StreamOrder,
     Video_Inform,
     Video_ID,
     Video_ID_String,
     Video_UniqueID,
+    Video_UniqueID_String,
     Video_MenuID,
     Video_MenuID_String,
     Video_Format,
     Video_Format_Info,
     Video_Format_Url,
+    Video_Format_Commercial,
+    Video_Format_Commercial_IfAny,
     Video_Format_Version,
     Video_Format_Profile,
+    Video_Format_Compression,
+    Video_MultiView_BaseProfile,
+    Video_MultiView_Count,
+    Video_MultiView_Layout,
     Video_Format_Settings,
     Video_Format_Settings_BVOP,
     Video_Format_Settings_BVOP_String,
@@ -375,8 +475,14 @@ enum video
     Video_Format_Settings_RefFrames,
     Video_Format_Settings_RefFrames_String,
     Video_Format_Settings_Pulldown,
+    Video_Format_Settings_FrameMode,
+    Video_Format_Settings_GOP,
+    Video_Format_Settings_FrameStructures,
+    Video_Format_Settings_Wrapping,
+    Video_InternetMediaType,
     Video_MuxingMode,
     Video_CodecID,
+    Video_CodecID_String,
     Video_CodecID_Info,
     Video_CodecID_Hint,
     Video_CodecID_Url,
@@ -404,6 +510,32 @@ enum video
     Video_Duration_String1,
     Video_Duration_String2,
     Video_Duration_String3,
+    Video_Duration_String4,
+    Video_Duration_FirstFrame,
+    Video_Duration_FirstFrame_String,
+    Video_Duration_FirstFrame_String1,
+    Video_Duration_FirstFrame_String2,
+    Video_Duration_FirstFrame_String3,
+    Video_Duration_LastFrame,
+    Video_Duration_LastFrame_String,
+    Video_Duration_LastFrame_String1,
+    Video_Duration_LastFrame_String2,
+    Video_Duration_LastFrame_String3,
+    Video_Source_Duration,
+    Video_Source_Duration_String,
+    Video_Source_Duration_String1,
+    Video_Source_Duration_String2,
+    Video_Source_Duration_String3,
+    Video_Source_Duration_FirstFrame,
+    Video_Source_Duration_FirstFrame_String,
+    Video_Source_Duration_FirstFrame_String1,
+    Video_Source_Duration_FirstFrame_String2,
+    Video_Source_Duration_FirstFrame_String3,
+    Video_Source_Duration_LastFrame,
+    Video_Source_Duration_LastFrame_String,
+    Video_Source_Duration_LastFrame_String1,
+    Video_Source_Duration_LastFrame_String2,
+    Video_Source_Duration_LastFrame_String3,
     Video_BitRate_Mode,
     Video_BitRate_Mode_String,
     Video_BitRate,
@@ -414,10 +546,20 @@ enum video
     Video_BitRate_Nominal_String,
     Video_BitRate_Maximum,
     Video_BitRate_Maximum_String,
+    Video_BitRate_Encoded,
+    Video_BitRate_Encoded_String,
     Video_Width,
     Video_Width_String,
+    Video_Width_Offset,
+    Video_Width_Offset_String,
+    Video_Width_Original,
+    Video_Width_Original_String,
     Video_Height,
     Video_Height_String,
+    Video_Height_Offset,
+    Video_Height_Offset_String,
+    Video_Height_Original,
+    Video_Height_Original_String,
     Video_PixelAspectRatio,
     Video_PixelAspectRatio_String,
     Video_PixelAspectRatio_Original,
@@ -426,44 +568,62 @@ enum video
     Video_DisplayAspectRatio_String,
     Video_DisplayAspectRatio_Original,
     Video_DisplayAspectRatio_Original_String,
+    Video_ActiveFormatDescription,
+    Video_ActiveFormatDescription_String,
+    Video_ActiveFormatDescription_MuxingMode,
     Video_Rotation,
     Video_Rotation_String,
     Video_FrameRate_Mode,
     Video_FrameRate_Mode_String,
+    Video_FrameRate_Mode_Original,
+    Video_FrameRate_Mode_Original_String,
     Video_FrameRate,
     Video_FrameRate_String,
+    Video_FrameRate_Original,
+    Video_FrameRate_Original_String,
     Video_FrameRate_Minimum,
     Video_FrameRate_Minimum_String,
     Video_FrameRate_Nominal,
     Video_FrameRate_Nominal_String,
     Video_FrameRate_Maximum,
     Video_FrameRate_Maximum_String,
-    Video_FrameRate_Original,
-    Video_FrameRate_Original_String,
     Video_FrameCount,
+    Video_Source_FrameCount,
     Video_Standard,
     Video_Resolution,
     Video_Resolution_String,
     Video_Colorimetry,
+    Video_ColorSpace,
+    Video_ChromaSubsampling,
+    Video_BitDepth,
+    Video_BitDepth_String,
     Video_ScanType,
     Video_ScanType_String,
     Video_ScanOrder,
     Video_ScanOrder_String,
     Video_Interlacement,
     Video_Interlacement_String,
+    Video_Compression_Mode,
+    Video_Compression_Mode_String,
+    Video_Compression_Ratio,
     Video_Bits__Pixel_Frame_,
     Video_Delay,
     Video_Delay_String,
     Video_Delay_String1,
     Video_Delay_String2,
     Video_Delay_String3,
+    Video_Delay_String4,
     Video_Delay_Settings,
+    Video_Delay_Source,
+    Video_Delay_Source_String,
     Video_Delay_Original,
     Video_Delay_Original_String,
     Video_Delay_Original_String1,
     Video_Delay_Original_String2,
     Video_Delay_Original_String3,
+    Video_Delay_Original_String4,
     Video_Delay_Original_Settings,
+    Video_Delay_Original_Source,
     Video_StreamSize,
     Video_StreamSize_String,
     Video_StreamSize_String1,
@@ -472,6 +632,30 @@ enum video
     Video_StreamSize_String4,
     Video_StreamSize_String5,
     Video_StreamSize_Proportion,
+    Video_Source_StreamSize,
+    Video_Source_StreamSize_String,
+    Video_Source_StreamSize_String1,
+    Video_Source_StreamSize_String2,
+    Video_Source_StreamSize_String3,
+    Video_Source_StreamSize_String4,
+    Video_Source_StreamSize_String5,
+    Video_Source_StreamSize_Proportion,
+    Video_StreamSize_Encoded,
+    Video_StreamSize_Encoded_String,
+    Video_StreamSize_Encoded_String1,
+    Video_StreamSize_Encoded_String2,
+    Video_StreamSize_Encoded_String3,
+    Video_StreamSize_Encoded_String4,
+    Video_StreamSize_Encoded_String5,
+    Video_StreamSize_Encoded_Proportion,
+    Video_Source_StreamSize_Encoded,
+    Video_Source_StreamSize_Encoded_String,
+    Video_Source_StreamSize_Encoded_String1,
+    Video_Source_StreamSize_Encoded_String2,
+    Video_Source_StreamSize_Encoded_String3,
+    Video_Source_StreamSize_Encoded_String4,
+    Video_Source_StreamSize_Encoded_String5,
+    Video_Source_StreamSize_Encoded_Proportion,
     Video_Alignment,
     Video_Alignment_String,
     Video_Title,
@@ -485,46 +669,67 @@ enum video
     Video_Encoded_Library_Settings,
     Video_Language,
     Video_Language_String,
+    Video_Language_String1,
+    Video_Language_String2,
+    Video_Language_String3,
+    Video_Language_String4,
     Video_Language_More,
+    Video_Default,
+    Video_Default_String,
+    Video_Forced,
+    Video_Forced_String,
     Video_Encoded_Date,
     Video_Tagged_Date,
     Video_Encryption,
+    Video_BufferSize,
 };
 
 //---------------------------------------------------------------------------
 enum audio
 {
     Audio_Count,
+    Audio_Status,
     Audio_StreamCount,
     Audio_StreamKind,
     Audio_StreamKind_String,
     Audio_StreamKindID,
     Audio_StreamKindPos,
+    Audio_StreamOrder,
     Audio_Inform,
     Audio_ID,
     Audio_ID_String,
     Audio_UniqueID,
+    Audio_UniqueID_String,
     Audio_MenuID,
     Audio_MenuID_String,
     Audio_Format,
     Audio_Format_Info,
     Audio_Format_Url,
+    Audio_Format_Commercial,
+    Audio_Format_Commercial_IfAny,
     Audio_Format_Version,
     Audio_Format_Profile,
+    Audio_Format_Compression,
     Audio_Format_Settings,
     Audio_Format_Settings_SBR,
     Audio_Format_Settings_SBR_String,
     Audio_Format_Settings_PS,
     Audio_Format_Settings_PS_String,
+    Audio_Format_Settings_Mode,
+    Audio_Format_Settings_ModeExtension,
+    Audio_Format_Settings_Emphasis,
     Audio_Format_Settings_Floor,
     Audio_Format_Settings_Firm,
     Audio_Format_Settings_Endianness,
     Audio_Format_Settings_Sign,
     Audio_Format_Settings_Law,
     Audio_Format_Settings_ITU,
+    Audio_Format_Settings_Wrapping,
+    Audio_InternetMediaType,
     Audio_MuxingMode,
     Audio_MuxingMode_MoreInfo,
     Audio_CodecID,
+    Audio_CodecID_String,
     Audio_CodecID_Info,
     Audio_CodecID_Hint,
     Audio_CodecID_Url,
@@ -550,6 +755,31 @@ enum audio
     Audio_Duration_String1,
     Audio_Duration_String2,
     Audio_Duration_String3,
+    Audio_Duration_FirstFrame,
+    Audio_Duration_FirstFrame_String,
+    Audio_Duration_FirstFrame_String1,
+    Audio_Duration_FirstFrame_String2,
+    Audio_Duration_FirstFrame_String3,
+    Audio_Duration_LastFrame,
+    Audio_Duration_LastFrame_String,
+    Audio_Duration_LastFrame_String1,
+    Audio_Duration_LastFrame_String2,
+    Audio_Duration_LastFrame_String3,
+    Audio_Source_Duration,
+    Audio_Source_Duration_String,
+    Audio_Source_Duration_String1,
+    Audio_Source_Duration_String2,
+    Audio_Source_Duration_String3,
+    Audio_Source_Duration_FirstFrame,
+    Audio_Source_Duration_FirstFrame_String,
+    Audio_Source_Duration_FirstFrame_String1,
+    Audio_Source_Duration_FirstFrame_String2,
+    Audio_Source_Duration_FirstFrame_String3,
+    Audio_Source_Duration_LastFrame,
+    Audio_Source_Duration_LastFrame_String,
+    Audio_Source_Duration_LastFrame_String1,
+    Audio_Source_Duration_LastFrame_String2,
+    Audio_Source_Duration_LastFrame_String3,
     Audio_BitRate_Mode,
     Audio_BitRate_Mode_String,
     Audio_BitRate,
@@ -560,37 +790,57 @@ enum audio
     Audio_BitRate_Nominal_String,
     Audio_BitRate_Maximum,
     Audio_BitRate_Maximum_String,
+    Audio_BitRate_Encoded,
+    Audio_BitRate_Encoded_String,
     Audio_Channel_s_,
     Audio_Channel_s__String,
     Audio_ChannelPositions,
     Audio_ChannelPositions_String2,
+    Audio_ChannelLayout,
     Audio_SamplingRate,
     Audio_SamplingRate_String,
     Audio_SamplingCount,
+    Audio_Source_SamplingCount,
+    Audio_FrameRate,
+    Audio_FrameRate_String,
+    Audio_FrameCount,
+    Audio_Source_FrameCount,
     Audio_Resolution,
     Audio_Resolution_String,
-    Audio_CompressionRatio,
+    Audio_BitDepth,
+    Audio_BitDepth_String,
+    Audio_Compression_Mode,
+    Audio_Compression_Mode_String,
+    Audio_Compression_Ratio,
     Audio_Delay,
     Audio_Delay_String,
     Audio_Delay_String1,
     Audio_Delay_String2,
     Audio_Delay_String3,
+    Audio_Delay_String4,
+    Audio_Delay_Settings,
+    Audio_Delay_Source,
+    Audio_Delay_Source_String,
     Audio_Delay_Original,
     Audio_Delay_Original_String,
     Audio_Delay_Original_String1,
     Audio_Delay_Original_String2,
     Audio_Delay_Original_String3,
+    Audio_Delay_Original_String4,
     Audio_Delay_Original_Settings,
+    Audio_Delay_Original_Source,
     Audio_Video_Delay,
     Audio_Video_Delay_String,
     Audio_Video_Delay_String1,
     Audio_Video_Delay_String2,
     Audio_Video_Delay_String3,
+    Audio_Video_Delay_String4,
     Audio_Video0_Delay,
     Audio_Video0_Delay_String,
     Audio_Video0_Delay_String1,
     Audio_Video0_Delay_String2,
     Audio_Video0_Delay_String3,
+    Audio_Video0_Delay_String4,
     Audio_ReplayGain_Gain,
     Audio_ReplayGain_Gain_String,
     Audio_ReplayGain_Peak,
@@ -602,6 +852,30 @@ enum audio
     Audio_StreamSize_String4,
     Audio_StreamSize_String5,
     Audio_StreamSize_Proportion,
+    Audio_Source_StreamSize,
+    Audio_Source_StreamSize_String,
+    Audio_Source_StreamSize_String1,
+    Audio_Source_StreamSize_String2,
+    Audio_Source_StreamSize_String3,
+    Audio_Source_StreamSize_String4,
+    Audio_Source_StreamSize_String5,
+    Audio_Source_StreamSize_Proportion,
+    Audio_StreamSize_Encoded,
+    Audio_StreamSize_Encoded_String,
+    Audio_StreamSize_Encoded_String1,
+    Audio_StreamSize_Encoded_String2,
+    Audio_StreamSize_Encoded_String3,
+    Audio_StreamSize_Encoded_String4,
+    Audio_StreamSize_Encoded_String5,
+    Audio_StreamSize_Encoded_Proportion,
+    Audio_Source_StreamSize_Encoded,
+    Audio_Source_StreamSize_Encoded_String,
+    Audio_Source_StreamSize_Encoded_String1,
+    Audio_Source_StreamSize_Encoded_String2,
+    Audio_Source_StreamSize_Encoded_String3,
+    Audio_Source_StreamSize_Encoded_String4,
+    Audio_Source_StreamSize_Encoded_String5,
+    Audio_Source_StreamSize_Encoded_Proportion,
     Audio_Alignment,
     Audio_Alignment_String,
     Audio_Interleave_VideoFrames,
@@ -618,7 +892,15 @@ enum audio
     Audio_Encoded_Library_Settings,
     Audio_Language,
     Audio_Language_String,
+    Audio_Language_String1,
+    Audio_Language_String2,
+    Audio_Language_String3,
+    Audio_Language_String4,
     Audio_Language_More,
+    Audio_Default,
+    Audio_Default_String,
+    Audio_Forced,
+    Audio_Forced_String,
     Audio_Encoded_Date,
     Audio_Tagged_Date,
     Audio_Encryption,
@@ -628,26 +910,35 @@ enum audio
 enum text
 {
     Text_Count,
+    Text_Status,
     Text_StreamCount,
     Text_StreamKind,
     Text_StreamKind_String,
     Text_StreamKindID,
     Text_StreamKindPos,
+    Text_StreamOrder,
     Text_Inform,
     Text_ID,
     Text_ID_String,
     Text_UniqueID,
+    Text_UniqueID_String,
     Text_MenuID,
     Text_MenuID_String,
     Text_Format,
     Text_Format_Info,
     Text_Format_Url,
+    Text_Format_Commercial,
+    Text_Format_Commercial_IfAny,
     Text_Format_Version,
     Text_Format_Profile,
+    Text_Format_Compression,
     Text_Format_Settings,
+    Text_Format_Settings_Wrapping,
+    Text_InternetMediaType,
     Text_MuxingMode,
     Text_MuxingMode_MoreInfo,
     Text_CodecID,
+    Text_CodecID_String,
     Text_CodecID_Info,
     Text_CodecID_Hint,
     Text_CodecID_Url,
@@ -662,6 +953,32 @@ enum text
     Text_Duration_String1,
     Text_Duration_String2,
     Text_Duration_String3,
+    Text_Duration_String4,
+    Text_Duration_FirstFrame,
+    Text_Duration_FirstFrame_String,
+    Text_Duration_FirstFrame_String1,
+    Text_Duration_FirstFrame_String2,
+    Text_Duration_FirstFrame_String3,
+    Text_Duration_LastFrame,
+    Text_Duration_LastFrame_String,
+    Text_Duration_LastFrame_String1,
+    Text_Duration_LastFrame_String2,
+    Text_Duration_LastFrame_String3,
+    Text_Source_Duration,
+    Text_Source_Duration_String,
+    Text_Source_Duration_String1,
+    Text_Source_Duration_String2,
+    Text_Source_Duration_String3,
+    Text_Source_Duration_FirstFrame,
+    Text_Source_Duration_FirstFrame_String,
+    Text_Source_Duration_FirstFrame_String1,
+    Text_Source_Duration_FirstFrame_String2,
+    Text_Source_Duration_FirstFrame_String3,
+    Text_Source_Duration_LastFrame,
+    Text_Source_Duration_LastFrame_String,
+    Text_Source_Duration_LastFrame_String1,
+    Text_Source_Duration_LastFrame_String2,
+    Text_Source_Duration_LastFrame_String3,
     Text_BitRate_Mode,
     Text_BitRate_Mode_String,
     Text_BitRate,
@@ -672,34 +989,64 @@ enum text
     Text_BitRate_Nominal_String,
     Text_BitRate_Maximum,
     Text_BitRate_Maximum_String,
+    Text_BitRate_Encoded,
+    Text_BitRate_Encoded_String,
     Text_Width,
     Text_Width_String,
     Text_Height,
     Text_Height_String,
+    Text_FrameRate_Mode,
+    Text_FrameRate_Mode_String,
+    Text_FrameRate,
+    Text_FrameRate_String,
+    Text_FrameRate_Minimum,
+    Text_FrameRate_Minimum_String,
+    Text_FrameRate_Nominal,
+    Text_FrameRate_Nominal_String,
+    Text_FrameRate_Maximum,
+    Text_FrameRate_Maximum_String,
+    Text_FrameRate_Original,
+    Text_FrameRate_Original_String,
     Text_FrameCount,
+    Text_Source_FrameCount,
+    Text_ColorSpace,
+    Text_ChromaSubsampling,
     Text_Resolution,
     Text_Resolution_String,
+    Text_BitDepth,
+    Text_BitDepth_String,
+    Text_Compression_Mode,
+    Text_Compression_Mode_String,
+    Text_Compression_Ratio,
     Text_Delay,
     Text_Delay_String,
     Text_Delay_String1,
     Text_Delay_String2,
     Text_Delay_String3,
+    Text_Delay_String4,
+    Text_Delay_Settings,
+    Text_Delay_Source,
+    Text_Delay_Source_String,
     Text_Delay_Original,
     Text_Delay_Original_String,
     Text_Delay_Original_String1,
     Text_Delay_Original_String2,
     Text_Delay_Original_String3,
+    Text_Delay_Original_String4,
     Text_Delay_Original_Settings,
+    Text_Delay_Original_Source,
     Text_Video_Delay,
     Text_Video_Delay_String,
     Text_Video_Delay_String1,
     Text_Video_Delay_String2,
     Text_Video_Delay_String3,
+    Text_Video_Delay_String4,
     Text_Video0_Delay,
     Text_Video0_Delay_String,
     Text_Video0_Delay_String1,
     Text_Video0_Delay_String2,
     Text_Video0_Delay_String3,
+    Text_Video0_Delay_String4,
     Text_StreamSize,
     Text_StreamSize_String,
     Text_StreamSize_String1,
@@ -708,6 +1055,30 @@ enum text
     Text_StreamSize_String4,
     Text_StreamSize_String5,
     Text_StreamSize_Proportion,
+    Text_Source_StreamSize,
+    Text_Source_StreamSize_String,
+    Text_Source_StreamSize_String1,
+    Text_Source_StreamSize_String2,
+    Text_Source_StreamSize_String3,
+    Text_Source_StreamSize_String4,
+    Text_Source_StreamSize_String5,
+    Text_Source_StreamSize_Proportion,
+    Text_StreamSize_Encoded,
+    Text_StreamSize_Encoded_String,
+    Text_StreamSize_Encoded_String1,
+    Text_StreamSize_Encoded_String2,
+    Text_StreamSize_Encoded_String3,
+    Text_StreamSize_Encoded_String4,
+    Text_StreamSize_Encoded_String5,
+    Text_StreamSize_Encoded_Proportion,
+    Text_Source_StreamSize_Encoded,
+    Text_Source_StreamSize_Encoded_String,
+    Text_Source_StreamSize_Encoded_String1,
+    Text_Source_StreamSize_Encoded_String2,
+    Text_Source_StreamSize_Encoded_String3,
+    Text_Source_StreamSize_Encoded_String4,
+    Text_Source_StreamSize_Encoded_String5,
+    Text_Source_StreamSize_Encoded_Proportion,
     Text_Title,
     Text_Encoded_Library,
     Text_Encoded_Library_String,
@@ -717,7 +1088,15 @@ enum text
     Text_Encoded_Library_Settings,
     Text_Language,
     Text_Language_String,
+    Text_Language_String1,
+    Text_Language_String2,
+    Text_Language_String3,
+    Text_Language_String4,
     Text_Language_More,
+    Text_Default,
+    Text_Default_String,
+    Text_Forced,
+    Text_Forced_String,
     Text_Summary,
     Text_Encoded_Date,
     Text_Tagged_Date,
@@ -733,6 +1112,7 @@ enum chapters
     Chapters_StreamKind_String,
     Chapters_StreamKindID,
     Chapters_StreamKindPos,
+    Chapters_StreamOrder,
     Chapters_Inform,
     Chapters_ID,
     Chapters_ID_String,
@@ -748,33 +1128,50 @@ enum chapters
     Chapters_Codec_Url,
     Chapters_Total,
     Chapters_Title,
-    Chapters_Language,
     Chapters_Language_String,
+    Chapters_Language_String1,
+    Chapters_Language_String2,
+    Chapters_Language_String3,
+    Chapters_Language_String4,
+    Chapters_Language_More,
+    Chapters_Default,
+    Chapters_Default_String,
+    Chapters_Forced,
+    Chapters_Forced_String,
 };
 
 //---------------------------------------------------------------------------
 enum image
 {
     Image_Count,
+    Image_Status,
     Image_StreamCount,
     Image_StreamKind,
     Image_StreamKind_String,
     Image_StreamKindID,
     Image_StreamKindPos,
+    Image_StreamOrder,
     Image_Inform,
     Image_ID,
     Image_ID_String,
     Image_UniqueID,
+    Image_UniqueID_String,
     Image_MenuID,
     Image_MenuID_String,
     Image_Title,
     Image_Format,
     Image_Format_Info,
     Image_Format_Url,
+    Image_Format_Commercial,
+    Image_Format_Commercial_IfAny,
     Image_Format_Version,
     Image_Format_Profile,
+    Image_Format_Compression,
     Image_Format_Settings,
+    Image_Format_Settings_Wrapping,
+    Image_InternetMediaType,
     Image_CodecID,
+    Image_CodecID_String,
     Image_CodecID_Info,
     Image_CodecID_Hint,
     Image_CodecID_Url,
@@ -786,10 +1183,33 @@ enum image
     Image_Codec_Url,
     Image_Width,
     Image_Width_String,
+    Image_Width_Offset,
+    Image_Width_Offset_String,
+    Image_Width_Original,
+    Image_Width_Original_String,
     Image_Height,
     Image_Height_String,
+    Image_Height_Offset,
+    Image_Height_Offset_String,
+    Image_Height_Original,
+    Image_Height_Original_String,
+    Image_PixelAspectRatio,
+    Image_PixelAspectRatio_String,
+    Image_PixelAspectRatio_Original,
+    Image_PixelAspectRatio_Original_String,
+    Image_DisplayAspectRatio,
+    Image_DisplayAspectRatio_String,
+    Image_DisplayAspectRatio_Original,
+    Image_DisplayAspectRatio_Original_String,
+    Image_ColorSpace,
+    Image_ChromaSubsampling,
     Image_Resolution,
     Image_Resolution_String,
+    Image_BitDepth,
+    Image_BitDepth_String,
+    Image_Compression_Mode,
+    Image_Compression_Mode_String,
+    Image_Compression_Ratio,
     Image_StreamSize,
     Image_StreamSize_String,
     Image_StreamSize_String1,
@@ -806,6 +1226,15 @@ enum image
     Image_Encoded_Library_Settings,
     Image_Language,
     Image_Language_String,
+    Image_Language_String1,
+    Image_Language_String2,
+    Image_Language_String3,
+    Image_Language_String4,
+    Image_Language_More,
+    Image_Default,
+    Image_Default_String,
+    Image_Forced,
+    Image_Forced_String,
     Image_Summary,
     Image_Encoded_Date,
     Image_Tagged_Date,
@@ -816,24 +1245,31 @@ enum image
 enum menu
 {
     Menu_Count,
+    Menu_Status,
     Menu_StreamCount,
     Menu_StreamKind,
     Menu_StreamKind_String,
     Menu_StreamKindID,
     Menu_StreamKindPos,
+    Menu_StreamOrder,
     Menu_Inform,
     Menu_ID,
     Menu_ID_String,
     Menu_UniqueID,
+    Menu_UniqueID_String,
     Menu_MenuID,
     Menu_MenuID_String,
     Menu_Format,
     Menu_Format_Info,
     Menu_Format_Url,
+    Menu_Format_Commercial,
+    Menu_Format_Commercial_IfAny,
     Menu_Format_Version,
     Menu_Format_Profile,
+    Menu_Format_Compression,
     Menu_Format_Settings,
     Menu_CodecID,
+    Menu_CodecID_String,
     Menu_CodecID_Info,
     Menu_CodecID_Hint,
     Menu_CodecID_Url,
@@ -842,6 +1278,21 @@ enum menu
     Menu_Codec_String,
     Menu_Codec_Info,
     Menu_Codec_Url,
+    Menu_Duration,
+    Menu_Duration_String,
+    Menu_Duration_String1,
+    Menu_Duration_String2,
+    Menu_Duration_String3,
+    Menu_Duration_Start,
+    Menu_Duration_End,
+    Menu_Delay,
+    Menu_Delay_String,
+    Menu_Delay_String1,
+    Menu_Delay_String2,
+    Menu_Delay_String3,
+    Menu_Delay_String4,
+    Menu_Delay_Settings,
+    Menu_Delay_Source,
     Menu_List_StreamKind,
     Menu_List_StreamPos,
     Menu_List,
@@ -849,6 +1300,10 @@ enum menu
     Menu_Title,
     Menu_Language,
     Menu_Language_String,
+    Menu_Language_String1,
+    Menu_Language_String2,
+    Menu_Language_String3,
+    Menu_Language_String4,
     Menu_Language_More,
     Menu_ServiceName,
     Menu_ServiceChannel,
