@@ -1,17 +1,17 @@
 // File__Analysze - Base for analyze files
-// Copyright (C) 2007-2011 MediaArea.net SARL, Info@MediaArea.net
+// Copyright (C) 2007-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // any later version.
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this library. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -27,7 +27,8 @@
 #include "MediaInfo/File__Base.h"
 #include "MediaInfo/File__Analyse_Automatic.h"
 #include "MediaInfo/MediaInfo_Config.h"
-#include "ZenLib/BitStream.h"
+#include "ZenLib/BitStream_Fast.h"
+#include "ZenLib/BitStream_LE.h"
 #include "ZenLib/int128u.h"
 #include "ZenLib/ZtringListList.h"
 #include <vector>
@@ -35,6 +36,7 @@
 #if MEDIAINFO_IBI
     #include "MediaInfo/Multiple/File_Ibi_Creation.h"
 #endif //MEDIAINFO_IBI
+#include "tinyxml2.h"
 using namespace ZenLib;
 //---------------------------------------------------------------------------
 
@@ -70,8 +72,8 @@ public :
     void    Open_Buffer_Init        (File__Analyze* Sub, int64u File_Size);
     void    Open_Buffer_Continue    (                    const int8u* Buffer, size_t Buffer_Size);
     void    Open_Buffer_Continue    (File__Analyze* Sub, const int8u* Buffer, size_t Buffer_Size);
-    void    Open_Buffer_Continue    (File__Analyze* Sub, size_t Buffer_Size) {Open_Buffer_Continue(Sub, Buffer+Buffer_Offset+(size_t)Element_Offset, Buffer_Size); Element_Offset+=Buffer_Size;}
-    void    Open_Buffer_Continue    (File__Analyze* Sub) {Open_Buffer_Continue(Sub, Buffer+Buffer_Offset+(size_t)Element_Offset, (size_t)(Element_Size-Element_Offset)); Element_Offset=Element_Size;}
+    void    Open_Buffer_Continue    (File__Analyze* Sub, size_t Buffer_Size) {if (Element_Offset+Buffer_Size<=Element_Size) Open_Buffer_Continue(Sub, Buffer+Buffer_Offset+(size_t)Element_Offset, Buffer_Size); Element_Offset+=Buffer_Size;}
+    void    Open_Buffer_Continue    (File__Analyze* Sub) {if (Element_Offset<=Element_Size) Open_Buffer_Continue(Sub, Buffer+Buffer_Offset+(size_t)Element_Offset, (size_t)(Element_Size-Element_Offset)); Element_Offset=Element_Size;}
     void    Open_Buffer_Position_Set(int64u File_Offset);
     #if MEDIAINFO_SEEK
     size_t  Open_Buffer_Seek        (size_t Method, int64u Value, int64u ID);
@@ -169,9 +171,11 @@ protected :
     virtual void Read_Buffer_Continue ()      {}; //Temp, should be in File__Base caller
     virtual void Read_Buffer_AfterParsing ()  {}; //Temp, should be in File__Base caller
     #if MEDIAINFO_SEEK
-    virtual size_t Read_Buffer_Seek (size_t, int64u, int64u) {return (size_t)-1;}; //Temp, should be in File__Base caller
+    virtual size_t Read_Buffer_Seek (size_t, int64u, int64u); //Temp, should be in File__Base caller
+    size_t Read_Buffer_Seek_OneFramePerFile (size_t, int64u, int64u);
     #endif //MEDIAINFO_SEEK
     virtual void Read_Buffer_Unsynched ()     {}; //Temp, should be in File__Base caller
+    void Read_Buffer_Unsynched_OneFramePerFile ();
     virtual void Read_Buffer_Finalize ()      {}; //Temp, should be in File__Base caller
     bool Buffer_Parse();
 
@@ -250,9 +254,12 @@ protected :
 
     //Elements - Begin
     void Element_Begin ();
-    void Element_Begin (const Ztring &Name, int64u Size=(int64u)-1);
-    inline void Element_Begin (int64u Size) {Element_Begin(Ztring(), Size);}
-    inline void Element_Begin (const char *Name, int64u Size=(int64u)-1) {Element_Begin(Ztring().From_UTF8(Name), Size);}
+    void Element_Begin (const Ztring &Name);
+    inline void Element_Begin (const char *Name) {Element_Begin(Ztring().From_UTF8(Name));}
+    #define Element_Begin0() Element_Begin()
+    #define Element_Begin1(_NAME) Element_Begin(_NAME)
+    #define Element_Trace_Begin0() Element_Begin()
+    #define Element_Trace_Begin1(_NAME) Element_Begin(_NAME)
 
     //Elements - Name
     void Element_Name (const Ztring &Name);
@@ -271,18 +278,25 @@ protected :
     inline void Element_Info (int64s        Parameter, const char*   Measure=NULL) {Element_Info(Ztring::ToZtring(Parameter)+Ztring().From_UTF8(Measure));}
     inline void Element_Info (int64u        Parameter, const char*   Measure=NULL) {Element_Info(Ztring::ToZtring(Parameter)+Ztring().From_UTF8(Measure));}
     inline void Element_Info (int128u       Parameter, const char*   Measure=NULL) {Element_Info(Ztring::ToZtring(Parameter)+Ztring().From_UTF8(Measure));}
-    #ifdef NEED_SIZET
+    #ifdef SIZE_T_IS_LONG
     inline void Element_Info (size_t        Parameter, const char*   Measure=NULL) {Element_Info(Ztring::ToZtring(Parameter)+Ztring().From_UTF8(Measure));}
-    #endif //NEED_SIZET
+    #endif //SIZE_T_IS_LONG
     inline void Element_Info (float32       Parameter, int8u AfterComma=3, const char*   Measure=NULL) {Element_Info(Ztring::ToZtring(Parameter, AfterComma)+Ztring().From_UTF8(Measure));}
     inline void Element_Info (float64       Parameter, int8u AfterComma=3, const char*   Measure=NULL) {Element_Info(Ztring::ToZtring(Parameter, AfterComma)+Ztring().From_UTF8(Measure));}
+    #define Element_Info1(_A) Element_Info(_A)
+    #define Element_Info2(_A,_B) Element_Info(_A, _B)
+    #define Element_Info3(_A,_B,_C) Element_Info(_A, _B, _C)
+    #define Element_Info1C(_CONDITION,_A) if (_CONDITION) Element_Info(_A)
     inline void Element_Info_From_Milliseconds (int64u Parameter)                  {Element_Info(Ztring().Duration_From_Milliseconds(Parameter));}
 
     //Elements - End
-    void Element_End ();
-    void Element_End (const Ztring &Name, int64u Size=(int64u)-1);
-    inline void Element_End (int64u Size) {Element_End(Ztring(), Size);}
-    inline void Element_End (const char *Name, int64u Size=(int64u)-1) {Element_End(Ztring().From_UTF8(Name), Size);}
+    inline void Element_End () {Element_End_Common_Flush();}
+    void Element_End (const Ztring &Name);
+    inline void Element_End (const char *Name) {Element_End(Ztring().From_UTF8(Name));}
+    #define Element_End0() Element_End()
+    #define Element_End1(_NAME) Element_End(_NAME)
+    #define Element_Trace_End0() Element_End()
+    #define Element_Trace_End1(_NAME) Element_End(_NAME)
 
     //Elements - Preparation of element from external app
     void Element_Prepare (int64u Size);
@@ -307,7 +321,7 @@ public :
             return Ztring().From_Local(Value, Value_Size);
     }
     #define VALUE(Value) \
-        Ztring::ToZtring(Value).MakeUpperCase()+_T(" (0x")+Ztring::ToZtring(Value, 16).MakeUpperCase()+_T(")")
+        Ztring::ToZtring(Value).MakeUpperCase()+__T(" (0x")+Ztring::ToZtring(Value, 16).MakeUpperCase()+__T(")")
 
     //Param - Main
     void Param      (const Ztring &Parameter, const Ztring& Value);
@@ -316,25 +330,28 @@ public :
     inline void Param      (const char*   Parameter, const char*   Value, size_t Value_Size=Unlimited, bool Utf8=true) {Param(Parameter, ToZtring(Value, Value_Size, Utf8));}
     inline void Param      (const char*   Parameter, const int8u*  Value, size_t Value_Size=Unlimited, bool Utf8=true) {Param(Parameter, (const char*)Value, Value_Size, Utf8);}
     inline void Param      (const char*   Parameter, bool   Value) {if (Value) Param(Parameter, "Yes"); else Param(Parameter, "No");}
-    inline void Param      (const char*   Parameter, int8u  Value) {Param(Parameter, Ztring::ToZtring(Value)+_T(" (0x")+Ztring().From_CC1(Value)+_T(")"));}
-    inline void Param      (const char*   Parameter, int8s  Value) {Param(Parameter, Ztring::ToZtring(Value)+_T(" (0x")+Ztring().From_CC1(Value)+_T(")"));}
-    inline void Param      (const char*   Parameter, int16u Value) {Param(Parameter, Ztring::ToZtring(Value)+_T(" (0x")+Ztring().From_CC2(Value)+_T(")"));}
-    inline void Param      (const char*   Parameter, int16s Value) {Param(Parameter, Ztring::ToZtring(Value)+_T(" (0x")+Ztring().From_CC2(Value)+_T(")"));}
-    inline void Param      (const char*   Parameter, int32u Value) {Param(Parameter, Ztring::ToZtring(Value)+_T(" (0x")+Ztring::ToZtring(Value, 16)+_T(")"));}
-    inline void Param      (const char*   Parameter, int32s Value) {Param(Parameter, Ztring::ToZtring(Value)+_T(" (0x")+Ztring::ToZtring(Value, 16)+_T(")"));}
-    inline void Param      (const char*   Parameter, int64u Value) {Param(Parameter, Ztring::ToZtring(Value)+_T(" (0x")+Ztring::ToZtring(Value, 16)+_T(")"));}
-    inline void Param      (const char*   Parameter, int64s Value) {Param(Parameter, Ztring::ToZtring(Value)+_T(" (0x")+Ztring::ToZtring(Value, 16)+_T(")"));}
-    inline void Param      (const char*   Parameter, int128u Value){Param(Parameter, Ztring::ToZtring(Value)+_T(" (0x")+Ztring::ToZtring(Value, 16)+_T(")"));}
+    inline void Param      (const char*   Parameter, int8u  Value) {Param(Parameter, Ztring::ToZtring(Value)+__T(" (0x")+Ztring().From_CC1(Value)+__T(")"));}
+    inline void Param      (const char*   Parameter, int8s  Value) {Param(Parameter, Ztring::ToZtring(Value)+__T(" (0x")+Ztring().From_CC1(Value)+__T(")"));}
+    inline void Param      (const char*   Parameter, int16u Value) {Param(Parameter, Ztring::ToZtring(Value)+__T(" (0x")+Ztring().From_CC2(Value)+__T(")"));}
+    inline void Param      (const char*   Parameter, int16s Value) {Param(Parameter, Ztring::ToZtring(Value)+__T(" (0x")+Ztring().From_CC2(Value)+__T(")"));}
+    inline void Param      (const char*   Parameter, int32u Value) {Param(Parameter, Ztring::ToZtring(Value)+__T(" (0x")+Ztring::ToZtring(Value, 16)+__T(")"));}
+    inline void Param      (const char*   Parameter, int32s Value) {Param(Parameter, Ztring::ToZtring(Value)+__T(" (0x")+Ztring::ToZtring(Value, 16)+__T(")"));}
+    inline void Param      (const char*   Parameter, int64u Value) {Param(Parameter, Ztring::ToZtring(Value)+__T(" (0x")+Ztring::ToZtring(Value, 16)+__T(")"));}
+    inline void Param      (const char*   Parameter, int64s Value) {Param(Parameter, Ztring::ToZtring(Value)+__T(" (0x")+Ztring::ToZtring(Value, 16)+__T(")"));}
+    inline void Param      (const char*   Parameter, int128u Value){Param(Parameter, Ztring::ToZtring(Value)+__T(" (0x")+Ztring::ToZtring(Value, 16)+__T(")"));}
     inline void Param_GUID (const char*   Parameter, int128u Value){Param(Parameter, Ztring().From_GUID(Value));}
     inline void Param_UUID (const char*   Parameter, int128u Value){Param(Parameter, Ztring().From_UUID(Value));}
-    #ifdef NEED_SIZET
-    inline void Param      (const char*   Parameter, size_t Value, intu Radix=16) {Param(Parameter, Ztring::ToZtring(Value, Radix).MakeUpperCase()+_T(" (")+Ztring::ToZtring(Value, 10).MakeUpperCase()+_T(")"));}
-    #endif //NEED_SIZET
+    #ifdef SIZE_T_IS_LONG
+    inline void Param      (const char*   Parameter, size_t Value, intu Radix=16) {Param(Parameter, Ztring::ToZtring(Value, Radix).MakeUpperCase()+__T(" (")+Ztring::ToZtring(Value, 10).MakeUpperCase()+__T(")"));}
+    #endif //SIZE_T_IS_LONG
     inline void Param      (const char*   Parameter, float32 Value, int8u AfterComma=3) {Param(Parameter, Ztring::ToZtring(Value, AfterComma));}
     inline void Param      (const char*   Parameter, float64 Value, int8u AfterComma=3) {Param(Parameter, Ztring::ToZtring(Value, AfterComma));}
     inline void Param      (const char*   Parameter, float80 Value, int8u AfterComma=3) {Param(Parameter, Ztring::ToZtring(Value, AfterComma));}
     inline void Param      (const int32u  Parameter, const Ztring& Value) {Param(Ztring().From_CC4(Parameter), Value);};
     inline void Param      (const int16u  Parameter, const Ztring& Value) {Param(Ztring().From_CC2(Parameter), Value);};
+    #define Param1(_A) Param_(_A)
+    #define Param2(_A,_B) Param(_A, _B)
+    #define Param3(_A,_B,_C) Param(_A, _B, _C)
 
     //Param - Info
     void Param_Info (const Ztring &Parameter);
@@ -351,9 +368,15 @@ public :
     inline void Param_Info (float32       Parameter, int8u AfterComma=3, const char*   Measure=NULL) {Param_Info(Ztring::ToZtring(Parameter, AfterComma)+Ztring().From_UTF8(Measure));}
     inline void Param_Info (float64       Parameter, int8u AfterComma=3, const char*   Measure=NULL) {Param_Info(Ztring::ToZtring(Parameter, AfterComma)+Ztring().From_UTF8(Measure));}
     inline void Param_Info (float80       Parameter, int8u AfterComma=3, const char*   Measure=NULL) {Param_Info(Ztring::ToZtring(Parameter, AfterComma)+Ztring().From_UTF8(Measure));}
-    #ifdef NEED_SIZET
+    #ifdef SIZE_T_IS_LONG
     inline void Param_Info (size_t        Parameter, const char*   Measure=NULL) {Param_Info(Ztring::ToZtring(Parameter)+Ztring().From_UTF8(Measure));}
-    #endif //NEED_SIZET
+    #endif //SIZE_T_IS_LONG
+    #define Param_Info1(_A) Param_Info(_A)
+    #define Param_Info2(_A,_B) Param_Info(_A, _B)
+    #define Param_Info3(_A,_B,_C) Param_Info(_A, _B, _C)
+    #define Param_Info1C(_CONDITION,_A) if (_CONDITION) Param_Info(_A)
+    #define Param_Info2C(_CONDITION,_A,_B) if (_CONDITION) Param_Info(_A, _B)
+    #define Param_Info3C(_CONDITION,_A,_B,_C) if (_CONDITION) Param_Info(_A, _B, _C)
     inline void Param_Info_From_Milliseconds (int64u Parameter)                  {Param_Info(Ztring().Duration_From_Milliseconds(Parameter));}
 
     //***************************************************************************
@@ -580,9 +603,29 @@ public :
     // Variable Length Code
     //***************************************************************************
 
-    void Get_VL (int32u Call(int8u Size, int32u ToCall), int32u &Info, const char* Name);
-    void Skip_VL(int32u Call(int8u Size, int32u ToCall),               const char* Name);
-    #define Info_VL(_CALL, _INFO, _NAME) int32u _INFO; Get_VL(_CALL, _INFO, _NAME)
+    struct vlc
+    {
+        int32u  value;
+        int8u   bit_increment;
+        int8s   mapped_to1;
+        int8s   mapped_to2;
+        int8s   mapped_to3;
+    };
+    struct vlc_fast
+    {
+        int8u*      Array;
+        int8u*      BitsToSkip;
+        const vlc*  Vlc;
+        int8u       Size;
+    };
+    #define VLC_END \
+        {(int32u)-1, (int8u)-1, 0, 0, 0}
+    void Get_VL_Prepare(vlc_fast &Vlc);
+    void Get_VL (const vlc Vlc[], size_t &Info, const char* Name);
+    void Get_VL (vlc_fast &Vlc, size_t &Info, const char* Name);
+    void Skip_VL(const vlc Vlc[], const char* Name);
+    void Skip_VL(vlc_fast &Vlc, const char* Name);
+    #define Info_VL(Vlc, Info, Name) size_t Info; Get_VL(Vlc, Info, Name)
 
     //***************************************************************************
     // Characters
@@ -619,6 +662,7 @@ public :
 
     void Get_Local  (int64u Bytes, Ztring      &Info, const char* Name);
     void Get_ISO_8859_1(int64u Bytes, Ztring   &Info, const char* Name);
+    void Get_ISO_8859_2(int64u Bytes, Ztring   &Info, const char* Name);
     void Get_String (int64u Bytes, std::string &Info, const char* Name);
     void Get_UTF8   (int64u Bytes, Ztring      &Info, const char* Name);
     void Get_UTF16  (int64u Bytes, Ztring      &Info, const char* Name);
@@ -659,6 +703,8 @@ public :
     void Get_Flags (int64u ValueToPut,          int8u &Info, const char* Name);
     void Skip_Flags(int64u Flags, size_t Order,              const char* Name);
     void Skip_Flags(int64u ValueToPut,                       const char* Name);
+    #define Get_FlagsM(_VALUE, _INFO, _NAME) Get_Flags(_VALUE, _INFO, _NAME)
+    #define Skip_FlagsM(_VALUE, _NAME) Skip_Flags(_VALUE, _NAME)
     #define Info_Flags(_FLAGS, _ORDER, _INFO, _NAME) bool _INFO; Get_Flags (_FLAGS, _ORDER, _INFO, _NAME)
 
     //***************************************************************************
@@ -719,7 +765,7 @@ public :
                 Skip_SB(                                        _NAME); \
             else \
             { \
-                Element_Begin(_NAME); \
+                Element_Begin1(_NAME); \
                 Skip_SB(                                        _NAME); \
 
     #define TEST_SB_SKIP(_NAME) \
@@ -728,7 +774,7 @@ public :
                 Skip_SB(                                        _NAME); \
             else \
             { \
-                Element_Begin(_NAME); \
+                Element_Begin1(_NAME); \
                 Skip_SB(                                        _NAME); \
 
     #define TESTELSE_SB_GET(_CODE, _NAME) \
@@ -736,18 +782,18 @@ public :
             Peek_SB(_CODE); \
             if (_CODE) \
             { \
-                Element_Begin(_NAME); \
+                Element_Begin1(_NAME); \
                 Skip_SB(                                        _NAME); \
 
     #define TESTELSE_SB_SKIP(_NAME) \
         { \
             if (Peek_SB()) \
             { \
-                Element_Begin(_NAME); \
+                Element_Begin1(_NAME); \
                 Skip_SB(                                        _NAME); \
 
     #define TESTELSE_SB_ELSE(_NAME) \
-                Element_End(); \
+                Element_End0(); \
             } \
             else \
             { \
@@ -758,7 +804,104 @@ public :
         } \
 
     #define TEST_SB_END() \
-                Element_End(); \
+                Element_End0(); \
+            } \
+        } \
+
+    //***************************************************************************
+    // BitStream (Little Endian)
+    //***************************************************************************
+
+    void Get_BT (size_t Bits, int32u  &Info, const char* Name);
+    void Get_TB (             bool    &Info, const char* Name);
+    bool Get_TB(                             const char* Name)  {bool Temp; Get_TB(Temp, Name); return Temp;}
+    void Get_T1 (size_t Bits, int8u   &Info, const char* Name);
+    void Get_T2 (size_t Bits, int16u  &Info, const char* Name);
+    void Get_T3 (size_t Bits, int32u  &Info, const char* Name);
+    void Get_T4 (size_t Bits, int32u  &Info, const char* Name);
+    void Get_T5 (size_t Bits, int64u  &Info, const char* Name);
+    void Get_T6 (size_t Bits, int64u  &Info, const char* Name);
+    void Get_T7 (size_t Bits, int64u  &Info, const char* Name);
+    void Get_T8 (size_t Bits, int64u  &Info, const char* Name);
+    void Peek_BT(size_t Bits, int32u  &Info);
+    void Peek_TB(              bool    &Info);
+    bool Peek_TB()                                              {bool Temp; Peek_TB(Temp); return Temp;}
+    void Peek_T1(size_t Bits, int8u   &Info);
+    void Peek_T2(size_t Bits, int16u  &Info);
+    void Peek_T3(size_t Bits, int32u  &Info);
+    void Peek_T4(size_t Bits, int32u  &Info);
+    void Peek_T5(size_t Bits, int64u  &Info);
+    void Peek_T6(size_t Bits, int64u  &Info);
+    void Peek_T7(size_t Bits, int64u  &Info);
+    void Peek_T8(size_t Bits, int64u  &Info);
+    void Skip_BT(size_t Bits,                const char* Name);
+    void Skip_TB(                            const char* Name);
+    void Skip_T1(size_t Bits,                const char* Name);
+    void Skip_T2(size_t Bits,                const char* Name);
+    void Skip_T3(size_t Bits,                const char* Name);
+    void Skip_T4(size_t Bits,                const char* Name);
+    void Skip_T5(size_t Bits,                const char* Name);
+    void Skip_T6(size_t Bits,                const char* Name);
+    void Skip_T7(size_t Bits,                const char* Name);
+    void Skip_T8(size_t Bits,                const char* Name);
+    #define Info_BT(_BITS, _INFO, _NAME) int32u  _INFO; Get_BT(_BITS, _INFO, _NAME)
+    #define Info_TB(_INFO, _NAME)        bool    _INFO; Get_TB(       _INFO, _NAME)
+    #define Info_T1(_BITS, _INFO, _NAME) int8u   _INFO; Get_T1(_BITS, _INFO, _NAME)
+    #define Info_T2(_BITS, _INFO, _NAME) int16u  _INFO; Get_T2(_BITS, _INFO, _NAME)
+    #define Info_T3(_BITS, _INFO, _NAME) int32u  _INFO; Get_T4(_BITS, _INFO, _NAME)
+    #define Info_T4(_BITS, _INFO, _NAME) int32u  _INFO; Get_T4(_BITS, _INFO, _NAME)
+    #define Info_T5(_BITS, _INFO, _NAME) int64u  _INFO; Get_T5(_BITS, _INFO, _NAME)
+    #define Info_T6(_BITS, _INFO, _NAME) int64u  _INFO; Get_T6(_BITS, _INFO, _NAME)
+    #define Info_T7(_BITS, _INFO, _NAME) int64u  _INFO; Get_T7(_BITS, _INFO, _NAME)
+    #define Info_T8(_BITS, _INFO, _NAME) int64u  _INFO; Get_T8(_BITS, _INFO, _NAME)
+
+    #define TEST_TB_GET(_CODE, _NAME) \
+        { \
+            Peek_TB(_CODE); \
+            if (!_CODE) \
+                Skip_TB(                                        _NAME); \
+            else \
+            { \
+                Element_Begin1(_NAME); \
+                Skip_TB(                                        _NAME); \
+
+    #define TEST_TB_SKIP(_NAME) \
+        { \
+            if (!Peek_TB()) \
+                Skip_TB(                                        _NAME); \
+            else \
+            { \
+                Element_Begin1(_NAME); \
+                Skip_TB(                                        _NAME); \
+
+    #define TESTELSE_TB_GET(_CODE, _NAME) \
+        { \
+            Peek_TB(_CODE); \
+            if (_CODE) \
+            { \
+                Element_Begin1(_NAME); \
+                Skip_TB(                                        _NAME); \
+
+    #define TESTELSE_TB_SKIP(_NAME) \
+        { \
+            if (Peek_TB()) \
+            { \
+                Element_Begin1(_NAME); \
+                Skip_TB(                                        _NAME); \
+
+    #define TESTELSE_TB_ELSE(_NAME) \
+                Element_End0(); \
+            } \
+            else \
+            { \
+                Skip_TB(                                        _NAME); \
+
+    #define TESTELSE_TB_END() \
+            } \
+        } \
+
+    #define TEST_TB_END() \
+                Element_End0(); \
             } \
         } \
 
@@ -800,9 +943,9 @@ public :
     inline void Fill (stream_t StreamKind, size_t StreamPos, size_t Parameter, float32        Value, int8u AfterComma=3, bool Replace=false) {Fill(StreamKind, StreamPos, Parameter, Ztring::ToZtring(Value, AfterComma), Replace);}
     inline void Fill (stream_t StreamKind, size_t StreamPos, size_t Parameter, float64        Value, int8u AfterComma=3, bool Replace=false) {Fill(StreamKind, StreamPos, Parameter, Ztring::ToZtring(Value, AfterComma), Replace);}
     inline void Fill (stream_t StreamKind, size_t StreamPos, size_t Parameter, float80        Value, int8u AfterComma=3, bool Replace=false) {Fill(StreamKind, StreamPos, Parameter, Ztring::ToZtring(Value, AfterComma), Replace);}
-    #ifdef NEED_SIZET
+    #ifdef SIZE_T_IS_LONG
     inline void Fill (stream_t StreamKind, size_t StreamPos, size_t Parameter, size_t         Value, int8u Radix=10, bool Replace=false) {Fill(StreamKind, StreamPos, Parameter, Ztring::ToZtring(Value, Radix).MakeUpperCase(), Replace);}
-    #endif //NEED_SIZET
+    #endif //SIZE_T_IS_LONG
     //Fill with datas
     void Fill (stream_t StreamKind, size_t StreamPos, const char* Parameter, const Ztring  &Value, bool Replace=false);
     inline void Fill (stream_t StreamKind, size_t StreamPos, const char* Parameter, const std::string &Value, bool Utf8=true, bool Replace=false) {if (Utf8) Fill(StreamKind, StreamPos, Parameter, Ztring().From_UTF8(Value.c_str(), Value.size())); else Fill(StreamKind, StreamPos, Parameter, Ztring().From_Local(Value.c_str(), Value.size()), Replace);}
@@ -819,9 +962,9 @@ public :
     inline void Fill (stream_t StreamKind, size_t StreamPos, const char* Parameter, float32        Value, int8u AfterComma=3, bool Replace=false) {Fill(StreamKind, StreamPos, Parameter, Ztring::ToZtring(Value, AfterComma), Replace);}
     inline void Fill (stream_t StreamKind, size_t StreamPos, const char* Parameter, float64        Value, int8u AfterComma=3, bool Replace=false) {Fill(StreamKind, StreamPos, Parameter, Ztring::ToZtring(Value, AfterComma), Replace);}
     inline void Fill (stream_t StreamKind, size_t StreamPos, const char* Parameter, float80        Value, int8u AfterComma=3, bool Replace=false) {Fill(StreamKind, StreamPos, Parameter, Ztring::ToZtring(Value, AfterComma), Replace);}
-    #ifdef NEED_SIZET
+    #ifdef SIZE_T_IS_LONG
     inline void Fill (stream_t StreamKind, size_t StreamPos, const char* Parameter, size_t         Value, int8u Radix=10, bool Replace=false) {Fill(StreamKind, StreamPos, Parameter, Ztring::ToZtring(Value, Radix).MakeUpperCase(), Replace);}
-    #endif //NEED_SIZET
+    #endif //SIZE_T_IS_LONG
     ZtringListList Fill_Temp;
     void Fill_Flush ();
     size_t Fill_Parameter(stream_t StreamKind, generic StreamPos);
@@ -934,6 +1077,7 @@ protected :
 
     void Tags ();
     void Video_FrameRate_Rounding (size_t Pos, video Parameter);
+    void Video_BitRate_Rounding (size_t Pos, video Parameter);
     void Audio_BitRate_Rounding (size_t Pos, audio Parameter);
 
     //Utils - Finalize
@@ -953,7 +1097,6 @@ protected :
     float                           Config_Trace_Level;
     std::bitset<32>                 Config_Trace_Layers;
     MediaInfo_Config::trace_Format  Config_Trace_Format;
-    float                           Config_ParseSpeed;
     int8u                           Config_Demux;
     Ztring                          Config_LineSeparator;
     bool                            IsSub;
@@ -989,7 +1132,10 @@ protected :
     const int8u* Buffer;
 public : //TO CHANGE
     size_t Buffer_Size;
+    int64u Buffer_TotalBytes;
     int64u Buffer_TotalBytes_FirstSynched;
+    int64u Buffer_PaddingBytes;
+    float64 Stream_BitRateFromContainer;
 protected :
     int8u* Buffer_Temp;
     size_t Buffer_Temp_Size;
@@ -998,7 +1144,6 @@ protected :
     size_t Buffer_Offset_Temp; //Temporary usage in this parser
     size_t Buffer_MinimumSize;
     size_t Buffer_MaximumSize;
-    int64u Buffer_TotalBytes;
     int64u Buffer_TotalBytes_FirstSynched_Max;
     int64u Buffer_TotalBytes_Fill_Max;
     friend class File__Tags_Helper;
@@ -1008,7 +1153,12 @@ protected :
     //***************************************************************************
 
     bool FileHeader_Begin_0x000001();
+    bool FileHeader_Begin_XML(tinyxml2::XMLDocument &Document);
     bool Synchronize_0x000001();
+public:
+    static void Streams_Accept_TestContinuousFileNames_Static(ZtringList &File_Names, bool IsReferenced);
+protected:
+    void Streams_Accept_TestContinuousFileNames();
 
 private :
 
@@ -1020,7 +1170,8 @@ private :
     size_t Data_Level;              //Current level for Data ("Top level")
 
     //Element
-    BitStream* BS;                  //For conversion from bytes to bitstream
+    BitStream_Fast* BS;             //For conversion from bytes to bitstream
+    BitStream*      BT;             //For conversion from bytes to bitstream
 public : //TO CHANGE
     int64u Header_Size;             //Size of the header of the current element
     const Ztring &Details_Get() {return Element[0].ToShow.Details;} //Direct access to details
@@ -1112,6 +1263,7 @@ public :
 
     //Configuration
     bool MustSynchronize;
+    bool CA_system_ID_MustSkipSlices;
 
     //Demux
     enum contenttype
@@ -1124,6 +1276,7 @@ public :
     #if MEDIAINFO_DEMUX
         void Demux (const int8u* Buffer, size_t Buffer_Size, contenttype ContentType);
         virtual bool Demux_UnpacketizeContainer_Test() {return true;}
+        bool Demux_UnpacketizeContainer_Test_OneFramePerFile();
         void Demux_UnpacketizeContainer_Demux(bool random_access=true);
         void Demux_UnpacketizeContainer_Demux_Clear();
         bool Demux_EventWasSent_Accept_Specific;
@@ -1136,12 +1289,29 @@ public :
     bool    PES_FirstByte_Value;
 
     int64u  Unsynch_Frame_Count;
+
+    #if MEDIAINFO_SEEK
+    private:
+        bool Seek_Duration_Detected;
+    #endif //MEDIAINFO_SEEK
+
     #if MEDIAINFO_IBI
     public:
         bool    Config_Ibi_Create;
         int64u  Ibi_SynchronizationOffset_Current;
         int64u  Ibi_SynchronizationOffset_BeginOfFrame;
-        ibi::stream IbiStream;
+        ibi::stream* IbiStream;
+        size_t  Ibi_Read_Buffer_Seek        (size_t Method, int64u Value, int64u ID);
+        void    Ibi_Read_Buffer_Unsynched   ();
+        void    Ibi_Stream_Finish           ();
+        void    Ibi_Stream_Finish           (int64u Numerator, int64u Denominator); //Partial
+        void    Ibi_Add                     ();
+    #else //MEDIAINFO_IBI
+        size_t  Ibi_Read_Buffer_Seek        (size_t, int64u, int64u)            {return (size_t)-1;}
+        void    Ibi_Read_Buffer_Unsynched   ()                                  {}
+        void    Ibi_Stream_Finish           ()                                  {}
+        void    Ibi_Stream_Finish           (int64u, int64u)                    {}
+        void    Ibi_Add                     ()                                  {}
     #endif //MEDIAINFO_IBI
 };
 
@@ -1205,6 +1375,12 @@ public :
                     } \
                     break; \
 
+#define ATOM_PARTIAL(_ATOM) \
+            case Elements::_ATOM : \
+                    if (Level==Element_Level) \
+                        _ATOM(); \
+                    break; \
+
 #define ATOM_DEFAULT(_ATOM) \
             default : \
                     if (Level==Element_Level) \
@@ -1264,6 +1440,20 @@ public :
     } \
     break; \
 
+#define LIST_DEFAULT_ALONE_BEGIN(_ATOM) \
+    if (Level!=Element_Level) \
+    { \
+        Level++; \
+        if (Level==Element_Level) \
+        { \
+            Element_ThisIsAList(); \
+            _ATOM(); \
+        } \
+
+#define LIST_DEFAULT_ALONE_END \
+    } \
+    break; \
+
 #define LIST_SKIP(_ATOM) \
     case Elements::_ATOM : \
             if (Level==Element_Level) \
