@@ -1,30 +1,34 @@
 // File__MultipleParsing - Info for MultipleParsing files
-// Copyright (C) 2007-2011 MediaArea.net SARL, Info@MediaArea.net
+// Copyright (C) 2007-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // any later version.
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this library. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
 //---------------------------------------------------------------------------
-// Compilation conditions
-#include "MediaInfo/Setup.h"
+// Pre-compilation
+#include "MediaInfo/PreComp.h"
 #ifdef __BORLANDC__
     #pragma hdrstop
 #endif
 //---------------------------------------------------------------------------
 
+//---------------------------------------------------------------------------
+#include "MediaInfo/Setup.h"
+//---------------------------------------------------------------------------
+
 //---------------------------------------------------------------------------
 #include "MediaInfo/File__MultipleParsing.h"
 //---------------------------------------------------------------------------
@@ -32,6 +36,9 @@
 #if defined(MEDIAINFO_CDXA_YES)
     #include "MediaInfo/Multiple/File_Cdxa.h"
 #endif
+#if defined(MEDIAINFO_DCP_YES)
+    #include "MediaInfo/Multiple/File_Dcp.h"
+#endif
 #if defined(MEDIAINFO_DPG_YES)
     #include "MediaInfo/Multiple/File_Dpg.h"
 #endif
@@ -50,6 +57,12 @@
 #if defined(MEDIAINFO_GXF_YES)
     #include "MediaInfo/Multiple/File_Gxf.h"
 #endif
+#if defined(MEDIAINFO_HLS_YES)
+    #include "MediaInfo/Multiple/File_Hls.h"
+#endif
+#if defined(MEDIAINFO_ISM_YES)
+    #include "MediaInfo/Multiple/File_Ism.h"
+#endif
 #if defined(MEDIAINFO_IVF_YES)
     #include "MediaInfo/Multiple/File_Ivf.h"
 #endif
@@ -86,6 +99,9 @@
 #if defined(MEDIAINFO_RM_YES)
     #include "MediaInfo/Multiple/File_Rm.h"
 #endif
+#if defined(MEDIAINFO_SEQUENCEINFO_YES)
+    #include "MediaInfo/Multiple/File_SequenceInfo.h"
+#endif
 #if defined(MEDIAINFO_SKM_YES)
     #include "MediaInfo/Multiple/File_Skm.h"
 #endif
@@ -113,6 +129,9 @@
 #if defined(MEDIAINFO_FLIC_YES)
     #include "MediaInfo/Video/File_Flic.h"
 #endif
+#if defined(MEDIAINFO_H263_YES)
+    #include "MediaInfo/Video/File_H263.h"
+#endif
 #if defined(MEDIAINFO_MPEG4V_YES)
     #include "MediaInfo/Video/File_Mpeg4v.h"
 #endif
@@ -125,6 +144,9 @@
 #if defined(MEDIAINFO_VC3_YES)
     #include "MediaInfo/Video/File_Vc3.h"
 #endif
+#if defined(MEDIAINFO_Y4M_YES)
+    #include "MediaInfo/Video/File_Y4m.h"
+#endif
 
 //---------------------------------------------------------------------------
 // Audio
@@ -185,6 +207,9 @@
 #if defined(MEDIAINFO_PCM_YES)
     #include "MediaInfo/Audio/File_Pcm.h"
 #endif
+#if defined(MEDIAINFO_RKAU_YES)
+    #include "MediaInfo/Audio/File_Rkau.h"
+#endif
 #if defined(MEDIAINFO_S3M_YES)
     #include "MediaInfo/Audio/File_ScreamTracker3.h"
 #endif
@@ -224,9 +249,15 @@
 #if defined(MEDIAINFO_JPEG_YES)
     #include "MediaInfo/Image/File_Jpeg.h"
 #endif
+#if defined(MEDIAINFO_PCX_YES)
+    #include "MediaInfo/Image/File_Pcx.h"
+#endif
 #if defined(MEDIAINFO_PNG_YES)
     #include "MediaInfo/Image/File_Png.h"
 #endif
+#if defined(MEDIAINFO_PSD_YES)
+    #include "MediaInfo/Image/File_Psd.h"
+#endif
 #if defined(MEDIAINFO_TIFF_YES)
     #include "MediaInfo/Image/File_Tiff.h"
 #endif
@@ -315,6 +346,9 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_CDXA_YES)
         Temp=new File_Cdxa(); Parser.push_back(Temp);
     #endif
+    #if defined(MEDIAINFO_DCP_YES)
+        Temp=new File_Dcp(); Parser.push_back(Temp);
+    #endif
     #if defined(MEDIAINFO_DPG_YES)
         Temp=new File_Dpg(); Parser.push_back(Temp);
     #endif
@@ -333,6 +367,12 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_GXF_YES)
         Temp=new File_Gxf(); Parser.push_back(Temp);
     #endif
+    #if defined(MEDIAINFO_HLS_YES)
+        Temp=new File_Hls(); Parser.push_back(Temp);
+    #endif
+    #if defined(MEDIAINFO_ISM_YES)
+        Temp=new File_Ism(); Parser.push_back(Temp);
+    #endif
     #if defined(MEDIAINFO_IVF_YES)
         Temp=new File_Ivf(); Parser.push_back(Temp);
     #endif
@@ -372,6 +412,9 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_RM_YES)
         Temp=new File_Rm(); Parser.push_back(Temp);
     #endif
+    #if defined(MEDIAINFO_SEQUENCEINFO_YES)
+        Temp=new File_SequenceInfo(); Parser.push_back(Temp);
+    #endif
     #if defined(MEDIAINFO_SKM_YES)
         Temp=new File_Skm(); Parser.push_back(Temp);
     #endif
@@ -398,6 +441,9 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_FLIC_YES)
         Temp=new File_Flic(); Parser.push_back(Temp);
     #endif
+    #if defined(MEDIAINFO_H263_YES)
+        Temp=new File_H263(); Parser.push_back(Temp);
+    #endif
     #if defined(MEDIAINFO_MPEG4V_YES)
         Temp=new File_Mpeg4v(); Parser.push_back(Temp);
     #endif
@@ -407,6 +453,9 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_VC1_YES)
         Temp=new File_Vc1(); Parser.push_back(Temp);
     #endif
+    #if defined(MEDIAINFO_Y4M_YES)
+        Temp=new File_Y4m(); Parser.push_back(Temp);
+    #endif
 
     // Audio
     #if defined(MEDIAINFO_AAC_YES)
@@ -463,6 +512,9 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_MPEGA_YES)
         Temp=new File_Mpega(); Parser.push_back(Temp);
     #endif
+    #if defined(MEDIAINFO_RKAU_YES)
+        Temp=new File_Rkau(); Parser.push_back(Temp);
+    #endif
     #if defined(MEDIAINFO_S3M_YES)
         Temp=new File_ScreamTracker3(); Parser.push_back(Temp);
     #endif
@@ -503,9 +555,15 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_JPEG_YES)
         Temp=new File_Jpeg(); Parser.push_back(Temp);
     #endif
+    #if defined(MEDIAINFO_PCX_YES)
+        Temp=new File_Pcx(); Parser.push_back(Temp);
+    #endif
     #if defined(MEDIAINFO_PNG_YES)
         Temp=new File_Png(); Parser.push_back(Temp);
     #endif
+    #if defined(MEDIAINFO_PSD_YES)
+        Temp=new File_Psd(); Parser.push_back(Temp);
+    #endif
     #if defined(MEDIAINFO_TIFF_YES)
         Temp=new File_Tiff(); Parser.push_back(Temp);
     #endif
@@ -661,4 +719,3 @@ void File__MultipleParsing::Read_Buffer_Continue()
 }
 
 } //NameSpace
-
