@@ -1,17 +1,17 @@
 // File_Jpeg - Info for NewFormat files
-// Copyright (C) 2005-2011 MediaArea.net SARL, Info@MediaArea.net
+// Copyright (C) 2005-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // any later version.
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this library. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -29,19 +29,24 @@
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
 //---------------------------------------------------------------------------
-// Compilation conditions
-#include "MediaInfo/Setup.h"
+// Pre-compilation
+#include "MediaInfo/PreComp.h"
 #ifdef __BORLANDC__
     #pragma hdrstop
 #endif
 //---------------------------------------------------------------------------
 
+//---------------------------------------------------------------------------
+#include "MediaInfo/Setup.h"
+//---------------------------------------------------------------------------
+
 //---------------------------------------------------------------------------
 #if defined(MEDIAINFO_JPEG_YES)
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/Image/File_Jpeg.h"
+#include "MediaInfo/MediaInfo_Config_MediaInfo.h"
 #include "ZenLib/Utils.h"
 #include <vector>
 using namespace ZenLib;
@@ -141,6 +146,14 @@ namespace Elements
     const int16u COM =0xFFFE;
 }
 
+//---------------------------------------------------------------------------
+// Borland C++ does not accept local template
+struct Jpeg_samplingfactor
+{
+    int8u Hi;
+    int8u Vi;
+};
+
 //***************************************************************************
 // Constructor/Destructor
 //***************************************************************************
@@ -168,8 +181,23 @@ File_Jpeg::File_Jpeg()
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-void File_Jpeg::Streams_Fill()
+void File_Jpeg::Streams_Accept()
 {
+    if (!IsSub)
+    {
+        Streams_Accept_TestContinuousFileNames();
+
+        Stream_Prepare(Config->File_Names.size()>1?Stream_Video:StreamKind);
+        Fill(StreamKind_Last, StreamPos_Last, "StreamSize", File_Size);
+        if (StreamKind_Last==Stream_Video)
+            Fill(Stream_Video, StreamPos_Last, Video_FrameCount, Config->File_Names.size());
+    }
+    else
+        Stream_Prepare(StreamKind);
+
+    //Configuration
+    Buffer_MaximumSize=64*1024*1024;
+    Frame_Count_NotParsedIncluded=0;
 }
 
 //***************************************************************************
@@ -180,16 +208,19 @@ void File_Jpeg::Streams_Fill()
 bool File_Jpeg::FileHeader_Begin()
 {
     //Element_Size
-    if (Buffer_Size<2)
+    if (Buffer_Size<3)
         return false; //Must wait for more data
 
-    if (CC2(Buffer)!=Elements::SOI
-     && CC2(Buffer)!=Elements::SOC)
+    if (Buffer[2]!=0xFF
+     || (CC2(Buffer)!=Elements::SOI
+      && CC2(Buffer)!=Elements::SOC))
     {
         Reject("JPEG");
         return false;
     }
 
+    Accept();
+
     //All should be OK...
     return true;
 }
@@ -220,7 +251,7 @@ bool File_Jpeg::Synchronize()
 //---------------------------------------------------------------------------
 bool File_Jpeg::Synched_Test()
 {
-    if (SOD_Parsed)
+    if (SOS_SOD_Parsed)
         return true; ///No sync after SOD
 
     //Must have enough buffer for having header
@@ -241,43 +272,9 @@ bool File_Jpeg::Synched_Test()
 //---------------------------------------------------------------------------
 void File_Jpeg::Synched_Init()
 {
-    SOD_Parsed=false;
+    SOS_SOD_Parsed=false;
 }
 
-//***************************************************************************
-// Buffer - Demux
-//***************************************************************************
-
-//---------------------------------------------------------------------------
-#if MEDIAINFO_DEMUX
-bool File_Jpeg::Demux_UnpacketizeContainer_Test()
-{
-    int16u code=BigEndian2int16u(Buffer+Buffer_Offset);
-    if (code==Elements::SOI || code==Elements::SOC)
-    {
-        if (Demux_Offset==0)
-        {
-            Demux_Offset=Buffer_Offset;
-        }
-        while (Demux_Offset+2<=Buffer_Size)
-        {
-            code=BigEndian2int16u(Buffer+Demux_Offset);
-            if (code==Elements::EOI)
-                break;
-            Demux_Offset++;
-        }
-
-        if (Demux_Offset+2>Buffer_Size && File_Offset+Buffer_Size!=File_Size)
-            return false; //No complete frame
-        Demux_Offset+=2; //EOI
-
-        Demux_UnpacketizeContainer_Demux();
-    }
-
-    return true;
-}
-#endif //MEDIAINFO_DEMUX
-
 //***************************************************************************
 // Buffer - Global
 //***************************************************************************
@@ -285,7 +282,9 @@ bool File_Jpeg::Demux_UnpacketizeContainer_Test()
 //---------------------------------------------------------------------------
 void File_Jpeg::Read_Buffer_Unsynched()
 {
-    SOD_Parsed=false;
+    SOS_SOD_Parsed=false;
+
+    Read_Buffer_Unsynched_OneFramePerFile();
 }
 
 //***************************************************************************
@@ -295,7 +294,7 @@ void File_Jpeg::Read_Buffer_Unsynched()
 //---------------------------------------------------------------------------
 void File_Jpeg::Header_Parse()
 {
-    if (SOD_Parsed)
+    if (SOS_SOD_Parsed)
     {
         Header_Fill_Code(0, "Data");
         if (!Header_Parser_Fill_Size())
@@ -362,13 +361,13 @@ bool File_Jpeg::Header_Parser_Fill_Size()
 void File_Jpeg::Data_Parse()
 {
     #define CASE_INFO(_NAME, _DETAIL) \
-        case Elements::_NAME : Element_Info(#_NAME); Element_Info(_DETAIL); _NAME(); break;
+        case Elements::_NAME : Element_Info1(#_NAME); Element_Info1(_DETAIL); _NAME(); break;
 
     //Parsing
-    if (SOD_Parsed)
+    if (SOS_SOD_Parsed)
     {
         Skip_XX(Element_Size,                                   "Data");
-        SOD_Parsed=false;
+        SOS_SOD_Parsed=false;
         return;
     }
     switch (Element_Code)
@@ -454,7 +453,7 @@ void File_Jpeg::Data_Parse()
         CASE_INFO(JPGC,                                         "JPG");
         CASE_INFO(JPGD,                                         "JPG");
         CASE_INFO(COM ,                                         "Comment");
-        default : Element_Info("Reserved");
+        default : Element_Info1("Reserved");
                   Skip_XX(Element_Size,                         "Data");
     }
 }
@@ -484,20 +483,23 @@ void File_Jpeg::SIZ()
     Get_B2 (Count,                                              "Components and initialize related arrays");
     for (int16u Pos=0; Pos<Count; Pos++)
     {
-        Element_Begin("Initialize related array");
-        int8u compSubsX, compSubsY;
+        Element_Begin1("Initialize related array");
+        int8u BitDepth, compSubsX, compSubsY;
         BS_Begin();
         Skip_SB(                                                "Signed");
-        Info_S1(7, BitDepth,                                    "BitDepth"); Param_Info(1+BitDepth); Element_Info(1+BitDepth);
+        Get_S1 (7, BitDepth,                                    "BitDepth"); Param_Info1(1+BitDepth); Element_Info1(1+BitDepth);
         BS_End();
-        Get_B1 (   compSubsX,                                   "compSubsX"); Element_Info(compSubsX);
-        Get_B1 (   compSubsY,                                   "compSubsY"); Element_Info(compSubsY);
-        Element_End();
+        Get_B1 (   compSubsX,                                   "compSubsX"); Element_Info1(compSubsX);
+        Get_B1 (   compSubsY,                                   "compSubsY"); Element_Info1(compSubsY);
+        Element_End0();
 
         //Filling list of HiVi
-        SamplingFactors.push_back(((float)compSubsY)/compSubsX);
-        if (((float)compSubsY)/compSubsX>SamplingFactors_Max)
-            SamplingFactors_Max=(int8u)((float)compSubsY)/compSubsX;
+        if (compSubsX)
+        {
+            SamplingFactors.push_back(((float)compSubsY)/compSubsX);
+            if (((float)compSubsY)/compSubsX>SamplingFactors_Max)
+                SamplingFactors_Max=(int8u)((float)compSubsY)/compSubsX;
+        }
 
         if (BitDepths.empty() || BitDepth!=BitDepths[0])
             BitDepths.push_back(BitDepth);
@@ -508,17 +510,17 @@ void File_Jpeg::SIZ()
         {
             Accept("JPEG 2000");
 
-            if (Count_Get(StreamKind)==0)
-                Stream_Prepare(StreamKind);
-            Fill(StreamKind, 0, Fill_Parameter(StreamKind, Generic_Format), StreamKind==Stream_Image?"JPEG 2000":"JPEG 2000");
-            Fill(StreamKind, 0, Fill_Parameter(StreamKind, Generic_Codec), StreamKind==Stream_Image?"JPEG 2000":"JPEG 2000");
-            if (StreamKind==Stream_Image)
+            if (Count_Get(StreamKind_Last)==0)
+                Stream_Prepare(StreamKind_Last);
+            Fill(StreamKind_Last, 0, Fill_Parameter(StreamKind_Last, Generic_Format), "JPEG 2000");
+            Fill(StreamKind_Last, 0, Fill_Parameter(StreamKind_Last, Generic_Codec), "JPEG 2000");
+            if (StreamKind_Last==Stream_Image)
                 Fill(Stream_Image, 0, Image_Codec_String, "JPEG 2000", Unlimited, true, true); //To Avoid automatic filling
-            Fill(StreamKind, 0, StreamKind==Stream_Image?(size_t)Image_Width:(size_t)Video_Width, Xsiz);
-            Fill(StreamKind, 0, StreamKind==Stream_Image?(size_t)Image_Height:(size_t)Video_Height, Ysiz*(Interlaced?2:1)); //If image is from interlaced content, must multiply height by 2
+            Fill(StreamKind_Last, 0, StreamKind_Last==Stream_Image?(size_t)Image_Width:(size_t)Video_Width, Xsiz);
+            Fill(StreamKind_Last, 0, StreamKind_Last==Stream_Image?(size_t)Image_Height:(size_t)Video_Height, Ysiz*(Interlaced?2:1)); //If image is from interlaced content, must multiply height by 2
 
             if (BitDepths.size()==1)
-                Fill(StreamKind, 0, Fill_Parameter(StreamKind, Generic_BitDepth), 1+BitDepths[0]);
+                Fill(StreamKind_Last, 0, Fill_Parameter(StreamKind_Last, Generic_BitDepth), 1+BitDepths[0]);
 
             //Chroma subsampling
             if (SamplingFactors_Max)
@@ -532,11 +534,11 @@ void File_Jpeg::SIZ()
                 SamplingFactors.push_back(0);
             Ztring ChromaSubsampling;
             for (size_t Pos=0; Pos<SamplingFactors.size(); Pos++)
-                ChromaSubsampling+=Ztring::ToZtring(SamplingFactors[Pos], 0)+_T(':');
+                ChromaSubsampling+=Ztring::ToZtring(SamplingFactors[Pos], 0)+__T(':');
             if (!ChromaSubsampling.empty())
             {
                 ChromaSubsampling.resize(ChromaSubsampling.size()-1);
-                Fill(StreamKind, 0, "ChromaSubsampling", ChromaSubsampling);
+                Fill(StreamKind_Last, 0, "ChromaSubsampling", ChromaSubsampling);
             }
         }
     FILLING_END();
@@ -556,8 +558,8 @@ void File_Jpeg::COD()
     Skip_B1(                                                    "Number of decomposition levels");
     Skip_B1(                                                    "Progression order");
     Get_B2 (Levels,                                             "Number of layers");
-    Info_B1(DimX,                                               "Code-blocks dimensions X (2^(n+2))"); Param_Info(1<<(DimX+2), " pixels");
-    Info_B1(DimY,                                               "Code-blocks dimensions Y (2^(n+2))"); Param_Info(1<<(DimY+2), " pixels");
+    Info_B1(DimX,                                               "Code-blocks dimensions X (2^(n+2))"); Param_Info2(1<<(DimX+2), " pixels");
+    Info_B1(DimY,                                               "Code-blocks dimensions Y (2^(n+2))"); Param_Info2(1<<(DimY+2), " pixels");
     Get_B1 (Style2,                                             "Style of the code-block coding passes");
         Skip_Flags(Style, 0,                                    "Selective arithmetic coding bypass");
         Skip_Flags(Style, 1,                                    "MQ states for all contexts");
@@ -575,12 +577,12 @@ void File_Jpeg::COD()
         BS_End();
         for (int16u Pos=0; Pos<Levels; Pos++)
         {
-            Element_Begin("Decomposition level");
+            Element_Begin1("Decomposition level");
             BS_Begin();
             Skip_S1(4,                                          "decomposition level width");
             Skip_S1(4,                                          "decomposition level height");
             BS_End();
-            Element_End();
+            Element_End0();
         }
     }
 
@@ -589,8 +591,8 @@ void File_Jpeg::COD()
         {
             switch (MultipleComponentTransform)
             {
-                case 0x01 : Fill(StreamKind, 0, StreamKind==Stream_Image?(size_t)Image_Compression_Mode:(size_t)Video_Compression_Mode, "Lossless"); break;
-                case 0x02 : Fill(StreamKind, 0, StreamKind==Stream_Image?(size_t)Image_Compression_Mode:(size_t)Video_Compression_Mode, "Lossy"); break;
+                case 0x01 : Fill(StreamKind_Last, 0, "Compression_Mode", "Lossless"); break;
+                case 0x02 : Fill(StreamKind_Last, 0, "Compression_Mode", "Lossy"); break;
                 default   : ;
             }
         }
@@ -608,22 +610,26 @@ void File_Jpeg::QCD()
 //---------------------------------------------------------------------------
 void File_Jpeg::SOD()
 {
-    FILLING_BEGIN_PRECISE();
-        SOD_Parsed=true;
-        if (Interlaced)
-            Field_Count++;
-        else
-            Frame_Count++;
+    SOS_SOD_Parsed=true;
+    if (Interlaced)
+        Field_Count++;
+    if (!Interlaced && Field_Count%2==0)
+    {
+        Frame_Count++;
+        if (Frame_Count_NotParsedIncluded!=(int64u)-1)
+            Frame_Count_NotParsedIncluded++;
+    }
+    if (Status[IsFilled])
+        Fill();
+    if (Config->ParseSpeed<1.0)
         Finish("JPEG 2000"); //No need of more
-    FILLING_END();
 }
 
 //---------------------------------------------------------------------------
 void File_Jpeg::SOF_()
 {
     //Parsing
-    vector<float> SamplingFactors;
-    int8u SamplingFactors_Max=0;
+    vector<Jpeg_samplingfactor> SamplingFactors;
     int16u Height, Width;
     int8u  Resolution, Count;
     Get_B1 (Resolution,                                         "P - Sample precision");
@@ -632,23 +638,18 @@ void File_Jpeg::SOF_()
     Get_B1 (Count,                                              "Nf - Number of image components in frame");
     for (int8u Pos=0; Pos<Count; Pos++)
     {
-        int8u Hi, Vi;
-        Element_Begin("Component");
-        Info_B1(Ci,                                             "Ci - Component identifier"); Element_Info(Ci);
+        Jpeg_samplingfactor SamplingFactor;
+        Element_Begin1("Component");
+        Info_B1(Ci,                                             "Ci - Component identifier"); Element_Info1(Ci);
         BS_Begin();
-        Get_S1 (4, Hi,                                          "Hi - Horizontal sampling factor"); Element_Info(Hi);
-        Get_S1 (4, Vi,                                          "Vi - Vertical sampling factor"); Element_Info(Vi);
+        Get_S1 (4, SamplingFactor.Hi,                           "Hi - Horizontal sampling factor"); Element_Info1(SamplingFactor.Hi);
+        Get_S1 (4, SamplingFactor.Vi,                           "Vi - Vertical sampling factor"); Element_Info1(SamplingFactor.Vi);
         BS_End();
         Skip_B1(                                                "Tqi - Quantization table destination selector");
-        Element_End();
+        Element_End0();
 
         //Filling list of HiVi
-        if (Vi)
-        {
-            SamplingFactors.push_back(((float)Hi)/Vi);
-            if (((float)Hi)/Vi>SamplingFactors_Max)
-                SamplingFactors_Max=(int8u)((float)Hi)/Vi;
-        }
+        SamplingFactors.push_back(SamplingFactor);
     }
 
     FILLING_BEGIN_PRECISE();
@@ -656,36 +657,51 @@ void File_Jpeg::SOF_()
         {
             Accept("JPEG");
 
-            if (Count_Get(StreamKind)==0)
-                Stream_Prepare(StreamKind);
-            Fill(StreamKind, 0, StreamKind==Stream_Image?(size_t)Image_Format:(size_t)Video_Format, StreamKind==Stream_Image?"JPEG":"JPEG");
-            Fill(StreamKind, 0, StreamKind==Stream_Image?(size_t)Image_Codec:(size_t)Video_Codec, StreamKind==Stream_Image?"JPEG":"JPEG");
-            if (StreamKind==Stream_Image)
+            if (Count_Get(StreamKind_Last)==0)
+                Stream_Prepare(StreamKind_Last);
+            Fill(StreamKind_Last, 0, Fill_Parameter(StreamKind_Last, Generic_Format), "JPEG");
+            Fill(StreamKind_Last, 0, Fill_Parameter(StreamKind_Last, Generic_Codec), "JPEG");
+            if (StreamKind_Last==Stream_Image)
                 Fill(Stream_Image, 0, Image_Codec_String, "JPEG", Unlimited, true, true); //To Avoid automatic filling
-            if (StreamKind==Stream_Video)
+            if (StreamKind_Last==Stream_Video)
                 Fill(Stream_Video, 0, Video_InternetMediaType, "video/JPEG", Unlimited, true, true);
-            Fill(Stream_Video, 0, Video_ColorSpace, "YUV");
-            Fill(StreamKind, 0, Fill_Parameter(StreamKind, Generic_BitDepth), Resolution);
-            Fill(StreamKind, 0, StreamKind==Stream_Image?(size_t)Image_Height:(size_t)Video_Height, Height*Height_Multiplier);
-            Fill(StreamKind, 0, StreamKind==Stream_Image?(size_t)Image_Width:(size_t)Video_Width, Width);
+            Fill(StreamKind_Last, 0, "ColorSpace", "YUV");
+            Fill(StreamKind_Last, 0, Fill_Parameter(StreamKind_Last, Generic_BitDepth), Resolution);
+            Fill(StreamKind_Last, 0, "Height", Height*Height_Multiplier);
+            Fill(StreamKind_Last, 0, "Width", Width);
 
             //Chroma subsampling
-            if (SamplingFactors_Max)
-                while (SamplingFactors_Max<4)
-                {
-                    for (size_t Pos=0; Pos<SamplingFactors.size(); Pos++)
-                        SamplingFactors[Pos]*=2;
-                    SamplingFactors_Max*=2;
-                }
-            while (SamplingFactors.size()<3)
-                SamplingFactors.push_back(0);
-            Ztring ChromaSubsampling;
-            for (size_t Pos=0; Pos<SamplingFactors.size(); Pos++)
-                ChromaSubsampling+=Ztring::ToZtring(SamplingFactors[Pos], 0)+_T(':');
-            if (!ChromaSubsampling.empty())
+            if (SamplingFactors.size()==3 && SamplingFactors[1].Hi==1 && SamplingFactors[2].Hi==1 && SamplingFactors[1].Vi==1 && SamplingFactors[2].Vi==1)
             {
-                ChromaSubsampling.resize(ChromaSubsampling.size()-1);
-                Fill(StreamKind, 0, "ChromaSubsampling", ChromaSubsampling);
+                string ChromaSubsampling;
+                switch (SamplingFactors[0].Hi)
+                {
+                    case 1 :
+                            switch (SamplingFactors[0].Vi)
+                            {
+                                case 1 : ChromaSubsampling="4:4:4"; break;
+                                default: ;
+                            }
+                            break;
+                    case 2 :
+                            switch (SamplingFactors[0].Vi)
+                            {
+                                case 1 : ChromaSubsampling="4:2:2"; break;
+                                case 2 : ChromaSubsampling="4:2:0"; break;
+                                default: ;
+                            }
+                            break;
+                    case 4 :
+                            switch (SamplingFactors[0].Vi)
+                            {
+                                case 1 : ChromaSubsampling="4:1:1"; break;
+                                default: ;
+                            }
+                            break;
+                    default: ;
+                }
+                if (!ChromaSubsampling.empty())
+                    Fill(StreamKind_Last, 0, "ChromaSubsampling", ChromaSubsampling);
             }
         }
     FILLING_END();
@@ -707,6 +723,18 @@ void File_Jpeg::SOS()
     Skip_B1(                                                    "Successive approximation bit position");
 
     FILLING_BEGIN_PRECISE();
+    SOS_SOD_Parsed=true;
+    if (Interlaced)
+        Field_Count++;
+    if (!Interlaced && Field_Count%2==0)
+    {
+        Frame_Count++;
+        if (Frame_Count_NotParsedIncluded!=(int64u)-1)
+            Frame_Count_NotParsedIncluded++;
+    }
+    if (Status[IsFilled])
+        Fill();
+    if (Config->ParseSpeed<1.0)
         Finish("JPEG"); //No need of more
     FILLING_END();
 }
@@ -731,7 +759,7 @@ void File_Jpeg::APP0_AVI1()
 {
     //Parsing
     int8u  FieldOrder=(int8u)-1;
-    Element_Begin("AVI1");
+    Element_Begin1("AVI1");
         if (Element_Size==16-4)
         {
             Get_B1 (FieldOrder,                                     "Field Order");
@@ -744,24 +772,17 @@ void File_Jpeg::APP0_AVI1()
             Skip_B4(                                                "Size of 1st Field");
             Skip_B4(                                                "Size of 2nd Field");
         }
-    Element_End();
+    Element_End0();
 
     FILLING_BEGIN();
         if (Frame_Count==0 && Field_Count==0)
         {
-            if (!Status[IsAccepted])
+            switch (FieldOrder)
             {
-                Accept("JPEG");
-                if (Count_Get(Stream_Video)==0)
-                    Stream_Prepare(Stream_Video);
-
-                switch (FieldOrder)
-                {
-                    case 0x00 : Fill(Stream_Video, 0, Video_Interlacement, "PPF"); Fill(Stream_Video, 0, Video_ScanType, "Progressive"); break;
-                    case 0x01 : Fill(Stream_Video, 0, Video_Interlacement, "TFF"); Fill(Stream_Video, 0, Video_ScanType, "Interlaced"); Fill(Stream_Video, 0, Video_ScanOrder, "TFF"); Height_Multiplier=2; break;
-                    case 0x02 : Fill(Stream_Video, 0, Video_Interlacement, "BFF"); Fill(Stream_Video, 0, Video_ScanType, "Interlaced"); Fill(Stream_Video, 0, Video_ScanOrder, "BFF"); Height_Multiplier=2; break;
-                    default   : ;
-                }
+                case 0x00 : Fill(Stream_Video, 0, Video_Interlacement, "PPF"); Fill(Stream_Video, 0, Video_ScanType, "Progressive"); break;
+                case 0x01 : Fill(Stream_Video, 0, Video_Interlacement, "TFF"); Fill(Stream_Video, 0, Video_ScanType, "Interlaced"); Fill(Stream_Video, 0, Video_ScanOrder, "TFF"); Height_Multiplier=2; break;
+                case 0x02 : Fill(Stream_Video, 0, Video_Interlacement, "BFF"); Fill(Stream_Video, 0, Video_ScanType, "Interlaced"); Fill(Stream_Video, 0, Video_ScanOrder, "BFF"); Height_Multiplier=2; break;
+                default   : ;
             }
         }
     FILLING_END();
@@ -772,7 +793,7 @@ void File_Jpeg::APP0_JFIF()
 {
     //Parsing
     Skip_B1(                                                    "Zero");
-    Element_Begin("JFIF");
+    Element_Begin1("JFIF");
         int16u Width, Height;
         int8u  Unit, ThumbailX, ThumbailY;
         Skip_B2(                                                "Version");
@@ -782,53 +803,53 @@ void File_Jpeg::APP0_JFIF()
         Get_B1 (ThumbailX,                                      "Xthumbail");
         Get_B1 (ThumbailY,                                      "Ythumbail");
         Skip_XX(3*ThumbailX*ThumbailY,                          "RGB Thumbail");
-    Element_End();
+    Element_End0();
 }
 
 //---------------------------------------------------------------------------
 void File_Jpeg::APP0_JFFF()
 {
     Skip_B1(                                                    "Zero");
-    Element_Begin("Extension");
+    Element_Begin1("Extension");
         Skip_B1(                                                "extension_code"); //0x10 Thumbnail coded using JPEG, 0x11 Thumbnail stored using 1 byte/pixel, 0x13 Thumbnail stored using 3 bytes/pixel
         if (Element_Size>Element_Offset)
             Skip_XX(Element_Size-Element_Offset,                "extension_data");
-    Element_End();
+    Element_End0();
 }
 
 //---------------------------------------------------------------------------
 void File_Jpeg::APP0_JFFF_JPEG()
 {
     //Parsing
-    Element_Begin("Thumbail JPEG");
+    Element_Begin1("Thumbail JPEG");
         if (Element_Size>Element_Offset)
             Skip_XX(Element_Size-Element_Offset,                "Data");
-    Element_End();
+    Element_End0();
 }
 
 //---------------------------------------------------------------------------
 void File_Jpeg::APP0_JFFF_1B()
 {
     //Parsing
-    Element_Begin("Thumbail 1 byte per pixel");
+    Element_Begin1("Thumbail 1 byte per pixel");
         int8u  ThumbailX, ThumbailY;
         Get_B1 (ThumbailX,                                      "Xthumbail");
         Get_B1 (ThumbailY,                                      "Ythumbail");
         Skip_XX(768,                                            "Palette");
         Skip_XX(ThumbailX*ThumbailY,                            "Thumbail");
-    Element_End();
+    Element_End0();
 }
 
 //---------------------------------------------------------------------------
 void File_Jpeg::APP0_JFFF_3B()
 {
     //Parsing
-    Element_Begin("Thumbail 3 bytes per pixel");
+    Element_Begin1("Thumbail 3 bytes per pixel");
         int8u  ThumbailX, ThumbailY;
         Get_B1 (ThumbailX,                                      "Xthumbail");
         Get_B1 (ThumbailY,                                      "Ythumbail");
         Skip_XX(3*ThumbailX*ThumbailY,                          "RGB Thumbail");
-    Element_End();
+    Element_End0();
 }
 
 //---------------------------------------------------------------------------
@@ -841,7 +862,7 @@ void File_Jpeg::APP1()
     switch (Name)
     {
         case 0x457869660000LL : APP1_EXIF(); break; //"Exif\0\0"
-        default               : Skip_XX(Element_Size,           "Data");
+        default               : Skip_XX(Element_Size-Element_Offset, "Data");
     }
 }
 
@@ -849,14 +870,14 @@ void File_Jpeg::APP1()
 void File_Jpeg::APP1_EXIF()
 {
     //Parsing
-    Element_Begin("Exif");
+    Element_Begin1("Exif");
         int32u Alignment;
         Get_C4(Alignment,                                       "Alignment");
         if (Alignment==0x49492A00)
             Skip_B4(                                            "First_IFD");
         if (Alignment==0x4D4D2A00)
             Skip_L4(                                            "First_IFD");
-    Element_End();
+    Element_End0();
 }
 
 } //NameSpace
