@@ -1,17 +1,17 @@
 // MediaInfo_Config_MediaInfo - Configuration class
-// Copyright (C) 2005-2011 MediaArea.net SARL, Info@MediaArea.net
+// Copyright (C) 2005-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // any later version.
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this library. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -27,6 +27,7 @@
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
+#include "MediaInfo/Setup.h"
 #include "MediaInfo/MediaInfo_Internal_Const.h"
 #if MEDIAINFO_EVENTS
     #include "MediaInfo/MediaInfo_Config.h"
@@ -54,6 +55,7 @@ class MediaInfo_Config_MediaInfo
 public :
     //Constructor/Destructor
     MediaInfo_Config_MediaInfo();
+    ~MediaInfo_Config_MediaInfo();
 
     //General
     Ztring Option (const String &Option, const String &Value=Ztring());
@@ -64,6 +66,12 @@ public :
     void          File_IsSub_Set (bool NewValue);
     bool          File_IsSub_Get ();
 
+    void          File_IsDetectingDuration_Set (bool NewValue);
+    bool          File_IsDetectingDuration_Get ();
+
+    void          File_IsReferenced_Set (bool NewValue);
+    bool          File_IsReferenced_Get ();
+
     void          File_KeepInfo_Set (bool NewValue);
     bool          File_KeepInfo_Get ();
 
@@ -85,6 +93,9 @@ public :
     void          File_FileName_Set (const Ztring &NewValue);
     Ztring        File_FileName_Get ();
 
+    void          File_FileNameFormat_Set (const Ztring &NewValue);
+    Ztring        File_FileNameFormat_Get ();
+
     void          File_TimeToLive_Set (float64 NewValue);
     float64       File_TimeToLive_Get ();
 
@@ -126,6 +137,13 @@ public :
     ZtringListList SubFile_Config_Get ();
     void          SubFile_StreamID_Set(int64u Value);
     int64u        SubFile_StreamID_Get();
+    void          SubFile_IDs_Set(Ztring Value);
+    Ztring        SubFile_IDs_Get();
+    #endif //MEDIAINFO_EVENTS
+
+    #if MEDIAINFO_EVENTS
+    bool          ParseUndecodableFrames_Get ();
+    void          ParseUndecodableFrames_Set (bool Value);
     #endif //MEDIAINFO_EVENTS
 
     #if MEDIAINFO_EVENTS
@@ -145,6 +163,12 @@ public :
     bool          Demux_Unpacketize_Get ();
     void          Demux_Rate_Set (float64 NewValue);
     float64       Demux_Rate_Get ();
+    void          Demux_FirstDts_Set (int64u NewValue);
+    int64u        Demux_FirstDts_Get ();
+    void          Demux_FirstFrameNumber_Set (int64u NewValue);
+    int64u        Demux_FirstFrameNumber_Get ();
+    void          Demux_InitData_Set (int8u NewValue);
+    int8u         Demux_InitData_Get ();
     #endif //MEDIAINFO_DEMUX
 
     #if MEDIAINFO_IBI
@@ -161,12 +185,26 @@ public :
     bool          File_MpegTs_stream_type_Trust_Get ();
     void          File_MpegTs_Atsc_transport_stream_id_Trust_Set (bool NewValue);
     bool          File_MpegTs_Atsc_transport_stream_id_Trust_Get ();
+    void          File_MpegTs_RealTime_Set (bool NewValue);
+    bool          File_MpegTs_RealTime_Get ();
     void          File_Bdmv_ParseTargetedFile_Set (bool NewValue);
     bool          File_Bdmv_ParseTargetedFile_Get ();
+    #if defined(MEDIAINFO_DVDIF_YES)
+    void          File_DvDif_DisableAudioIfIsInContainer_Set (bool NewValue);
+    bool          File_DvDif_DisableAudioIfIsInContainer_Get ();
+    void          File_DvDif_IgnoreTransmittingFlags_Set (bool NewValue);
+    bool          File_DvDif_IgnoreTransmittingFlags_Get ();
+    #endif //defined(MEDIAINFO_DVDIF_YES)
     #if defined(MEDIAINFO_DVDIF_ANALYZE_YES)
     void          File_DvDif_Analysis_Set (bool NewValue);
     bool          File_DvDif_Analysis_Get ();
     #endif //defined(MEDIAINFO_DVDIF_ANALYZE_YES)
+    #if MEDIAINFO_MACROBLOCKS
+    void          File_Macroblocks_Parse_Set (bool NewValue);
+    bool          File_Macroblocks_Parse_Get ();
+    #endif //MEDIAINFO_MACROBLOCKS
+    void          File_GrowingFile_Delay_Set(float64 Value);
+    float64       File_GrowingFile_Delay_Get();
     #if defined(MEDIAINFO_LIBCURL_YES)
     void          File_Curl_Set (const Ztring &NewValue);
     void          File_Curl_Set (const Ztring &Field, const Ztring &NewValue);
@@ -186,13 +224,33 @@ public :
     float         State_Get ();
 
     //Internal to MediaInfo, not thread safe
+    ZtringList    File_Names;
+    std::vector<int64u> File_Sizes;
+    size_t        File_Names_Pos;
+    size_t        File_Buffer_Size_Max;
+    size_t        File_Buffer_Size_ToRead;
+    size_t        File_Buffer_Size;
+    int8u*        File_Buffer;
+    bool          File_Buffer_Repeat;
+    bool          File_Buffer_Repeat_IsSupported;
+    bool          File_IsGrowing;
+    bool          File_IsNotGrowingAnymore;
+    int64u        File_Current_Offset;
+    int64u        File_Current_Size;
+    int64u        File_Size;
+    float32       ParseSpeed;
     #if MEDIAINFO_DEMUX
     bool          Demux_EventWasSent;
+        #if MEDIAINFO_SEEK
+        bool      Demux_IsSeeking;
+        #endif //MEDIAINFO_SEEK
     #endif //MEDIAINFO_DEMUX
 
 private :
     bool                    FileIsSeekable;
     bool                    FileIsSub;
+    bool                    FileIsDetectingDuration;
+    bool                    FileIsReferenced;
     bool                    FileKeepInfo;
     bool                    FileStopAfterFilled;
     bool                    FileStopSubStreamAfterFilled;
@@ -200,6 +258,7 @@ private :
     bool                    File_Demux_Interleave;
     bool                    File_ID_OnlyRoot;
     Ztring                  File_FileName;
+    Ztring                  File_FileNameFormat;
     float64                 File_TimeToLive;
     Ztring                  File_Partial_Begin;
     Ztring                  File_Partial_End;
@@ -227,6 +286,8 @@ private :
     void*                   Event_UserHandler;
     ZtringListList          SubFile_Config;
     int64u                  SubFile_StreamID;
+    bool                    ParseUndecodableFrames;
+    Ztring                  SubFile_IDs;
     #endif //MEDIAINFO_EVENTS
 
     #if MEDIAINFO_DEMUX
@@ -234,6 +295,9 @@ private :
     bool                    Demux_PCM_20bitTo16bit;
     bool                    Demux_Unpacketize;
     float64                 Demux_Rate;
+    int64u                  Demux_FirstDts;
+    int64u                  Demux_FirstFrameNumber;
+    int8u                   Demux_InitData;
     #endif //MEDIAINFO_DEMUX
 
     #if MEDIAINFO_IBI
@@ -245,10 +309,19 @@ private :
     bool                    File_MpegTs_ForceMenu;
     bool                    File_MpegTs_stream_type_Trust;
     bool                    File_MpegTs_Atsc_transport_stream_id_Trust;
+    bool                    File_MpegTs_RealTime;
     bool                    File_Bdmv_ParseTargetedFile;
-    #if defined(MEDIAINFO_DVDIF_ANALYZE_YES)
+    #if defined(MEDIAINFO_DVDIF_YES)
+    bool                    File_DvDif_DisableAudioIfIsInContainer;
+    bool                    File_DvDif_IgnoreTransmittingFlags;
+    #endif //defined(MEDIAINFO_DVDIF_ANALYZE_YES)
+    #if defined(MEDIAINFO_DVDIF_YES)
     bool                    File_DvDif_Analysis;
     #endif //defined(MEDIAINFO_DVDIF_ANALYZE_YES)
+    #if MEDIAINFO_MACROBLOCKS
+    bool                    File_Macroblocks_Parse;
+    #endif //MEDIAINFO_MACROBLOCKS
+    float64                 File_GrowingFile_Delay;
     #if defined(MEDIAINFO_LIBMMS_YES)
     bool                    File_Mmsh_Describe_Only;
     #endif //defined(MEDIAINFO_LIBMMS_YES)
@@ -269,4 +342,3 @@ private :
 } //NameSpace
 
 #endif
-
