@@ -1,17 +1,17 @@
 // File_Flv - Info for Flash files
-// Copyright (C) 2005-2011 MediaArea.net SARL, Info@MediaArea.net
+// Copyright (C) 2005-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // any later version.
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this library. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -28,13 +28,17 @@
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
-// Compilation conditions
-#include "MediaInfo/Setup.h"
+// Pre-compilation
+#include "MediaInfo/PreComp.h"
 #ifdef __BORLANDC__
     #pragma hdrstop
 #endif
 //---------------------------------------------------------------------------
 
+//---------------------------------------------------------------------------
+#include "MediaInfo/Setup.h"
+//---------------------------------------------------------------------------
+
 //---------------------------------------------------------------------------
 #if defined(MEDIAINFO_FLV_YES)
 //---------------------------------------------------------------------------
@@ -53,6 +57,7 @@
 #if defined(MEDIAINFO_RM_YES)
     #include "MediaInfo/Multiple/File_Rm.h"
 #endif
+#include "MediaInfo/MediaInfo_Config_MediaInfo.h"
 #if MEDIAINFO_EVENTS
     #include "MediaInfo/MediaInfo_Events.h"
 #endif //MEDIAINFO_EVENTS
@@ -168,7 +173,7 @@ const char* Flv_Format_Video[]=
 {
     "",
     "",
-    "H.263",
+    "Sorenson Spark",
     "Screen video",
     "VP6",
     "VP6",
@@ -228,7 +233,7 @@ const char* Flv_CodecID_Hint_Video[]=
 {
     "",
     "",
-    "Sorenson",
+    "",
     "",
     "",
     "",
@@ -420,7 +425,7 @@ File_Flv::File_Flv()
 :File__Analyze()
 {
     //Configuration
-    ParserName=_T("FLV");
+    ParserName=__T("FLV");
     #if MEDIAINFO_EVENTS
         ParserIDs[0]=MediaInfo_Parser_Flv;
         StreamIDs_Width[0]=2;
@@ -491,9 +496,9 @@ void File_Flv::Streams_Fill()
         Merge(*Stream[Stream_Audio].Parser, Stream_Audio, 0, 0);
 
         //Special case: AAC
-        if (Retrieve(Stream_Audio, 0, Audio_Format)==_T("AAC")
-         || Retrieve(Stream_Audio, 0, Audio_Format)==_T("MPEG Audio")
-         || Retrieve(Stream_Audio, 0, Audio_Format)==_T("Vorbis"))
+        if (Retrieve(Stream_Audio, 0, Audio_Format)==__T("AAC")
+         || Retrieve(Stream_Audio, 0, Audio_Format)==__T("MPEG Audio")
+         || Retrieve(Stream_Audio, 0, Audio_Format)==__T("Vorbis"))
             Clear(Stream_Audio, 0, Audio_BitDepth); //Resolution is not valid for AAC / MPEG Audio / Vorbis
     }
 
@@ -596,7 +601,7 @@ void File_Flv::Streams_Finish_PerStream(stream_t StreamKind)
 void File_Flv::FileHeader_Parse()
 {
     //Parsing
-    Element_Begin("FLV header");
+    Element_Begin1("FLV header");
     std::string Signature;
     int32u Size;
     int8u  Version, Flags;
@@ -608,7 +613,7 @@ void File_Flv::FileHeader_Parse()
     Get_B4 (Size,                                               "Size");
     if (Size>9)
         Skip_XX(Size-9,                                         "Unknown");
-    Element_End();
+    Element_End0();
 
     FILLING_BEGIN();
         //Integrity
@@ -622,6 +627,12 @@ void File_Flv::FileHeader_Parse()
         Accept();
 
         Fill(Stream_General, 0, General_Format, "Flash Video");
+        if (!video_stream_Count && !audio_stream_Count)
+        {
+            //TODO: quick and awful hack for a file having both bools unset, should detect directly the streams
+            video_stream_Count=true;
+            audio_stream_Count=true;
+        }
         if (video_stream_Count)
         {
             Stream_Prepare(Stream_Video);
@@ -719,14 +730,25 @@ void File_Flv::Header_Parse()
     {
         int32u Timestamp_Base;
         int8u  Timestamp_Extended;
-        Get_B1 (Type,                                           "Type"); //Param_Info(Type<19?Flv_Type[Type]:_T("Unknown"));
+        Get_B1 (Type,                                           "Type"); //Param_Info1(Type<19?Flv_Type[Type]:__T("Unknown"));
         Get_B3 (BodyLength,                                     "BodyLength");
         Get_B3 (Timestamp_Base,                                 "Timestamp_Base"); //in ms
         Get_B1 (Timestamp_Extended,                             "Timestamp_Extended"); //TimeStamp = Timestamp_Extended*0x01000000+Timestamp_Base
         Skip_B3(                                                "StreamID");
 
+        // For audio, check if it's just an audio config.
+        bool Skip_Timestamps=false;
+        if (Type==0x08)
+        {
+            int16u  Format_Info;
+            Peek_B2(Format_Info);
+            int8u   Format=(Format_Info>>12)&0x0F;
+            if (Format==10 && (Format_Info&0xFF)==0) // AAC sequence header
+                Skip_Timestamps=true;
+        }
+
         //Filling
-        if (Type==0x08 || Type==0x09)
+        if ((Type==0x08 && !Skip_Timestamps) || Type==0x09)
         {
             Time=(((int32u)Timestamp_Extended)<<24)|Timestamp_Base;
             stream_t StreamKind=(Type==0x08)?Stream_Audio:Stream_Video;
@@ -784,7 +806,7 @@ void File_Flv::Data_Parse()
         if ((((Count_Get(Stream_Video)==0 || Stream[Stream_Video].TimeStamp!=(int32u)-1)
            && (Count_Get(Stream_Audio)==0 || Stream[Stream_Audio].TimeStamp!=(int32u)-1))
           || (File_Size>65536*2 && File_Offset+Buffer_Offset-Header_Size-PreviousTagSize-4<File_Size-65536))
-         && Config_ParseSpeed<1)
+         && Config->ParseSpeed<1)
             Finish();
         else if (Element_Code==0xFA) //RM metadata have a malformed PreviousTagSize, always
         {
@@ -803,7 +825,7 @@ void File_Flv::Data_Parse()
         Fill();
 
         //Trying to find the last frame for duration
-        Open_Buffer_Unsynch();
+        Read_Buffer_Unsynched(); //This is not synched yet, so we call directly this method instead of Open_Buffer_Unsynched
         GoToFromEnd(4, "FLV");
         Searching_Duration=true;
     }
@@ -818,7 +840,7 @@ void File_Flv::video()
 {
     Element_Name("Video");
     Stream[Stream_Video].PacketCount++;
-    Element_Info(Stream[Stream_Video].PacketCount);
+    Element_Info1(Stream[Stream_Video].PacketCount);
 
     //Handling FrameRate
     if (!video_stream_FrameRate_Detected)
@@ -831,28 +853,24 @@ void File_Flv::video()
 
     if (Element_Size==0) //Header says that video is present, but there is only one null packet
     {
-        Element_Info("Null");
+        Element_Info1("Null");
         return;
     }
 
     Demux(Buffer+Buffer_Offset+(size_t)Element_Offset, (size_t)(Element_Size-Element_Offset), ContentType_MainStream);
 
     //Needed?
-    if (!video_stream_Count && Config_ParseSpeed<1)
+    if (!video_stream_Count && Config->ParseSpeed<1)
         return; //No more need of Video stream
 
-    //Delay
-    if (Stream[Stream_Video].Delay==(int32u)-1)
-        Stream[Stream_Video].Delay=Time;
-
     //Parsing
     int8u Codec, FrameType;
-    Element_Begin("Stream header");
+    Element_Begin1("Stream header");
     BS_Begin();
-    Get_S1 (4, FrameType,                                       "frameType"); Param_Info(Flv_FrameType[FrameType]);
-    Get_S1 (4, Codec,                                           "codecID"); Param_Info(Flv_Codec_Video[Codec]); Element_Info(Flv_Codec_Video[Codec]);
+    Get_S1 (4, FrameType,                                       "frameType"); Param_Info1(Flv_FrameType[FrameType]);
+    Get_S1 (4, Codec,                                           "codecID"); Param_Info1(Flv_Codec_Video[Codec]); Element_Info1(Flv_Codec_Video[Codec]);
     BS_End();
-    Element_End();
+    Element_End0();
 
     FILLING_BEGIN();
         //Filling
@@ -899,10 +917,10 @@ void File_Flv::video_H263()
     if (Version>1)
         return;
     Skip_S1( 8,                                                 "TemporalReference");
-    Get_S1 ( 3, PictureSize,                                    "PictureSize"); Param_Info(Flv_H263_PictureSize[PictureSize]);
+    Get_S1 ( 3, PictureSize,                                    "PictureSize"); Param_Info1(Flv_H263_PictureSize[PictureSize]);
     switch (PictureSize)
     {
-        case 0 :
+        case 0 :
             Get_S2 ( 8, Width,                                  "Width");
             Get_S2 ( 8, Height,                                 "Height");
             break;
@@ -917,7 +935,7 @@ void File_Flv::video_H263()
                 Height=Flv_H263_WidthHeight[PictureSize][1];
             }
     }
-    Get_S1 ( 2, PictureType,                                    "PictureSize"); Param_Info(Flv_H263_PictureType[PictureType]);
+    Get_S1 ( 2, PictureType,                                    "PictureSize"); Param_Info1(Flv_H263_PictureType[PictureType]);
     Skip_SB(                                                    "DeblockingFlag");
     Skip_S1( 5,                                                 "Quantizer");
     Get_SB (    ExtraInformationFlag,                           "ExtraInformationFlag");
@@ -941,9 +959,9 @@ void File_Flv::video_ScreenVideo(int8u Version)
     //Parsing
     int16u Width, Height;
     BS_Begin();
-    Info_S1( 4, BlockWidth,                                     "BlockWidth"); Param_Info((BlockWidth+1)*16);
+    Info_S1( 4, BlockWidth,                                     "BlockWidth"); Param_Info1((BlockWidth+1)*16);
     Get_S2 (12, Width,                                          "ImageWidth");
-    Info_S1( 4, BlockHeight,                                    "BlockHeight"); Param_Info((BlockHeight+1)*16);
+    Info_S1( 4, BlockHeight,                                    "BlockHeight"); Param_Info1((BlockHeight+1)*16);
     Get_S2 (12, Height,                                         "ImageHeight");
     if (Version==2)
     {
@@ -973,9 +991,9 @@ void File_Flv::video_VP6(bool WithAlpha)
     Get_S1 ( 4, VerticalAdjustment,                             "VerticalAdjustment");
     if (WithAlpha)
         Skip_S3(24,                                             "OffsetToAlpha");
-    Get_SB (    FrameMode,                                      "FrameMode"); Param_Info(Flv_VP6_FrameMode[FrameMode]);
+    Get_SB (    FrameMode,                                      "FrameMode"); Param_Info1(Flv_VP6_FrameMode[FrameMode]);
     Skip_S1( 6,                                                 "Quantization");
-    Get_SB (    Marker,                                         "Marker"); Param_Info(Flv_VP6_Marker[Marker]);
+    Get_SB (    Marker,                                         "Marker"); Param_Info1(Flv_VP6_Marker[Marker]);
     BS_End();
     if (FrameMode)
     {
@@ -994,8 +1012,8 @@ void File_Flv::video_VP6(bool WithAlpha)
             Skip_B2(                                            "Offset");
         Skip_B1(                                                "MacroBlock_Height");
         Skip_B1(                                                "MacroBlock_Width");
-        Get_B1 (Height,                                         "Height"); Param_Info(Ztring::ToZtring(Height*16)+_T(" pixels"));
-        Get_B1 (Width,                                          "Width"); Param_Info(Ztring::ToZtring(Width*16)+_T(" pixels"));
+        Get_B1 (Height,                                         "Height"); Param_Info1(Ztring::ToZtring(Height*16)+__T(" pixels"));
+        Get_B1 (Width,                                          "Width"); Param_Info1(Ztring::ToZtring(Width*16)+__T(" pixels"));
 
         FILLING_BEGIN();
             if (Width && Height)
@@ -1012,8 +1030,8 @@ void File_Flv::video_VP6(bool WithAlpha)
 void File_Flv::video_AVC()
 {
     int8u AVCPacketType;
-    Get_B1 (AVCPacketType,                                      "AVCPacketType"); Param_Info(Flv_AVCPacketType(AVCPacketType));
-    Info_B3(CompositionTime,                                    "CompositionTime"); Param_Info(Ztring::ToZtring((int32s)(CompositionTime+0xFF000000)));
+    Get_B1 (AVCPacketType,                                      "AVCPacketType"); Param_Info1(Flv_AVCPacketType(AVCPacketType));
+    Info_B3(CompositionTime,                                    "CompositionTime"); Param_Info1(Ztring::ToZtring((int32s)(CompositionTime+0xFF000000)));
 
     switch (AVCPacketType)
     {
@@ -1048,7 +1066,7 @@ void File_Flv::video_AVC()
                     Open_Buffer_Continue(Stream[Stream_Video].Parser);
 
                     //Disabling this stream
-                    if (Stream[Stream_Video].Parser->File_GoTo!=(int64u)-1 || Stream[Stream_Video].Parser->Count_Get(Stream_Video)>0)
+                    if (Stream[Stream_Video].Parser->File_GoTo!=(int64u)-1 || Stream[Stream_Video].Parser->Count_Get(Stream_Video)>0 || (Config->ParseSpeed<1.0 && Stream[Stream_Video].PacketCount>=300))
                          video_stream_Count=false;
                 #else
                     Skip_XX(Element_Size-Element_Offset,        "AVC Data");
@@ -1064,35 +1082,31 @@ void File_Flv::audio()
 {
     Element_Name("Audio");
     Stream[Stream_Audio].PacketCount++;
-    Element_Info(Stream[Stream_Audio].PacketCount);
+    Element_Info1(Stream[Stream_Audio].PacketCount);
 
     if (Element_Size==0) //Header says that audio is present, but there is only one null packet
     {
-        Element_Info("Null");
+        Element_Info1("Null");
         return;
     }
 
     Demux(Buffer+Buffer_Offset+(size_t)Element_Offset+1, (size_t)(Element_Size-Element_Offset-1), ContentType_MainStream);
 
     //Needed?
-    if (!audio_stream_Count && Config_ParseSpeed<1)
+    if (!audio_stream_Count && Config->ParseSpeed<1)
         return; //No more need of Audio stream
 
-    //Delay
-    if (Stream[Stream_Audio].Delay==(int32u)-1)
-        Stream[Stream_Audio].Delay=Time;
-
     //Parsing
     int8u  codec, sampling_rate;
     bool   is_16bit, is_stereo;
-    Element_Begin("Stream header");
+    Element_Begin1("Stream header");
     BS_Begin();
-    Get_S1 (4, codec,                                           "codec"); Param_Info(Flv_Codec_Audio[codec]); Element_Info(Flv_Codec_Audio[codec]);
-    Get_S1 (2, sampling_rate,                                   "sampling_rate"); Param_Info(Ztring::ToZtring(Flv_SamplingRate[sampling_rate])+_T(" Hz"));
-    Get_SB (   is_16bit,                                        "is_16bit"); Param_Info(Ztring::ToZtring(Flv_Resolution[is_16bit])+_T(" bits"));
-    Get_SB (   is_stereo,                                       "is_stereo"); Param_Info(Ztring::ToZtring(Flv_Channels[is_stereo])+_T(" channel(s)"));
+    Get_S1 (4, codec,                                           "codec"); Param_Info1(Flv_Codec_Audio[codec]); Element_Info1(Flv_Codec_Audio[codec]);
+    Get_S1 (2, sampling_rate,                                   "sampling_rate"); Param_Info1(Ztring::ToZtring(Flv_SamplingRate[sampling_rate])+__T(" Hz"));
+    Get_SB (   is_16bit,                                        "is_16bit"); Param_Info1(Ztring::ToZtring(Flv_Resolution[is_16bit])+__T(" bits"));
+    Get_SB (   is_stereo,                                       "is_stereo"); Param_Info1(Ztring::ToZtring(Flv_Channels[is_stereo])+__T(" channel(s)"));
     BS_End();
-    Element_End();
+    Element_End0();
 
     //Special case
     if (codec==5) //Nellymoser 8kHz mono
@@ -1164,7 +1178,7 @@ void File_Flv::audio_MPEG()
 void File_Flv::audio_AAC()
 {
     int8u AACPacketType;
-    Get_B1 (AACPacketType,                                      "AACPacketType"); Param_Info(Flv_AACPacketType(AACPacketType));
+    Get_B1 (AACPacketType,                                      "AACPacketType"); Param_Info1(Flv_AACPacketType(AACPacketType));
 
     switch (AACPacketType)
     {
@@ -1231,22 +1245,26 @@ void File_Flv::meta_SCRIPTDATAVARIABLE()
 {
     std::string StringData;
     int16u StringLength;
-    Element_Begin();
+    Element_Begin0();
     Get_B2 (StringLength,                                       "StringLength");
     Get_String(StringLength, StringData,                        "StringData");
     Element_Name(StringData.c_str());
 
     //Parsing Value
     meta_SCRIPTDATAVALUE(StringData);
-    Element_End();
+    Element_End0();
 }
 
 //---------------------------------------------------------------------------
 void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
 {
+    std::string StringDataModified(StringData);
+    if (!StringDataModified.empty() && StringDataModified[0]==__T('_'))
+        StringDataModified.erase(StringDataModified.begin());
+
     //Parsing
     int8u Type;
-    Get_B1 (Type,                                               "Type"); if (Type<0x12) Param_Info(Flv_TagType[Type]);
+    Get_B1 (Type,                                               "Type"); Param_Info1C((Type<0x12), Flv_TagType[Type]);
     switch (Type)
     {
         case 0x00 : //DOUBLE --> 64 bits Big endian float
@@ -1258,48 +1276,47 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
                 std::string ToFill;
                 Ztring ValueS;
                 stream_t StreamKind=Stream_General;
-                     if (StringData=="width") {ToFill="Width"; StreamKind=Stream_Video; ValueS.From_Number(Value, 0); video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
-                else if (StringData=="height") {ToFill="Height"; StreamKind=Stream_Video; ValueS.From_Number(Value, 0); video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
-                else if (StringData=="duration") meta_duration=Value*1000;
-                else if (StringData=="audiodatarate") {ToFill="BitRate"; StreamKind=Stream_Audio; ValueS.From_Number(Value*1000, 0);}
-                else if (StringData=="framerate") {ToFill="FrameRate"; StreamKind=Stream_Video; ValueS.From_Number(Value, 3); video_stream_FrameRate_Detected=true; video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
-                else if (StringData=="videoframerate") {ToFill="FrameRate"; StreamKind=Stream_Video; ValueS.From_Number(Value, 3); video_stream_FrameRate_Detected=true; video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
-                else if (StringData=="datasize") {}
-                else if (StringData=="lasttimestamp") {}
-                else if (StringData=="filesize") {meta_filesize=(int64u)Value;}
-                else if (StringData=="audiosize") {ToFill="StreamSize"; StreamKind=Stream_Audio; ValueS.From_Number(Value, 0); if (Value>File_Size) MetaData_NotTrustable=true;}
-                else if (StringData=="videosize") {ToFill="StreamSize"; StreamKind=Stream_Video; ValueS.From_Number(Value, 0); if (Value>File_Size) MetaData_NotTrustable=true; video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
-                else if (StringData=="videodatarate") {ToFill="BitRate"; StreamKind=Stream_Video; ValueS.From_Number(Value*1000, 0); video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
-                else if (StringData=="lastkeyframetimestamp") {}
-                else if (StringData=="lastkeyframelocation") {}
-                else if (StringData=="videocodecid") {; video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
-                else if (StringData=="audiocodecid") {}
-                else if (StringData=="audiodelay") {ToFill="Delay"; StreamKind=Stream_Audio; if (Value>0) ValueS.From_Number(Value*1000, 0);}
-                else if (StringData=="canSeekToEnd") {}
-                else if (StringData=="keyframes_times") {}
-                else if (StringData=="keyframes_filepositions") {}
-                else if (StringData=="audiosamplerate") {ToFill="SamplingRate"; StreamKind=Stream_Audio; if (Value>0) ValueS.From_Number(Value, 0);}
-                else if (StringData=="audiosamplesize") {ToFill="BitDepth"; StreamKind=Stream_Audio; if (Value>0) ValueS.From_Number(Value, 0);}
-                else if (StringData=="totalduration") {ToFill="Duration"; StreamKind=Stream_General; ValueS.From_Number(Value*1000, 0);}
-                else if (StringData=="totaldatarate") {ToFill="OverallBitRate"; StreamKind=Stream_General; ValueS.From_Number(Value*1000, 0);}
-                else if (StringData=="bytelength") {if (File_Size!=Value) MetaData_NotTrustable=true;}
-                else if (StringData=="aacaot") {}
-                else if (StringData=="audiochannels") {}
-                else if (StringData=="audiocodecid") {}
-                else if (StringData=="avclevel") {}
-                else if (StringData=="avcprofile") {}
-                else if (StringData=="moovPosition") {}
-                else {StreamKind=Stream_General; ToFill=StringData; ValueS.From_Number(Value);}
+                     if (StringDataModified=="width") {ToFill="Width"; StreamKind=Stream_Video; ValueS.From_Number(Value, 0); video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
+                else if (StringDataModified=="height") {ToFill="Height"; StreamKind=Stream_Video; ValueS.From_Number(Value, 0); video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
+                else if (StringDataModified=="duration") meta_duration=Value*1000;
+                else if (StringDataModified=="audiodatarate") {ToFill="BitRate"; StreamKind=Stream_Audio; ValueS.From_Number(Value*1000, 0);}
+                else if (StringDataModified=="framerate") {ToFill="FrameRate"; StreamKind=Stream_Video; ValueS.From_Number(Value, 3); video_stream_FrameRate_Detected=true; video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
+                else if (StringDataModified=="videoframerate") {ToFill="FrameRate"; StreamKind=Stream_Video; ValueS.From_Number(Value, 3); video_stream_FrameRate_Detected=true; video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
+                else if (StringDataModified=="filesize") {meta_filesize=(int64u)Value;}
+                else if (StringDataModified=="audiosize") {ToFill="StreamSize"; StreamKind=Stream_Audio; ValueS.From_Number(Value, 0); if (Value>File_Size) MetaData_NotTrustable=true;}
+                else if (StringDataModified=="videosize") {ToFill="StreamSize"; StreamKind=Stream_Video; ValueS.From_Number(Value, 0); if (Value>File_Size) MetaData_NotTrustable=true; video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
+                else if (StringDataModified=="videodatarate") {ToFill="BitRate"; StreamKind=Stream_Video; ValueS.From_Number(Value*1000, 0); video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
+                else if (StringDataModified=="videocodecid") {; video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
+                else if (StringDataModified=="audiodelay") {ToFill="Delay"; StreamKind=Stream_Audio; if (Value>0) ValueS.From_Number(Value*1000, 0);}
+                else if (StringDataModified=="audiosamplerate") {ToFill="SamplingRate"; StreamKind=Stream_Audio; if (Value>0) ValueS.From_Number(Value, 0);}
+                else if (StringDataModified=="audiosamplesize") {ToFill="BitDepth"; StreamKind=Stream_Audio; if (Value>0) ValueS.From_Number(Value, 0);}
+                else if (StringDataModified=="totalduration") {ToFill="Duration"; StreamKind=Stream_General; ValueS.From_Number(Value*1000, 0);}
+                else if (StringDataModified=="totaldatarate") {ToFill="OverallBitRate"; StreamKind=Stream_General; ValueS.From_Number(Value*1000, 0);}
+                else if (StringDataModified=="totalframes") {ToFill="FrameCount"; StreamKind=Stream_Video; ValueS.From_Number(Value*1000, 0);}
+                else if (StringDataModified=="bytelength") {if (File_Size!=Value) MetaData_NotTrustable=true;}
+                else if (!(StringDataModified=="datasize"
+                       || StringDataModified=="lasttimestamp"
+                       || StringDataModified=="lastkeyframetimestamp"
+                       || StringDataModified=="lastkeyframelocation"
+                       || StringDataModified=="canSeekToEnd"
+                       || StringDataModified=="keyframes_times"
+                       || StringDataModified=="keyframes_filepositions"
+                       || StringDataModified=="aacaot"
+                       || StringDataModified=="audiochannels"
+                       || StringDataModified=="audiocodecid"
+                       || StringDataModified=="avclevel"
+                       || StringDataModified=="avcprofile"
+                       || StringDataModified=="moovPosition")) {StreamKind=Stream_General; ToFill=StringData; ValueS.From_Number(Value);}
                 #if MEDIAINFO_TRACE
                     if (ValueS.empty())
                         ValueS.From_Number(Value, 0);
-                    Element_Info(ValueS);
+                    Element_Info1(ValueS);
                 #endif //MEDIAINFO_TRACE
                 if (!ToFill.empty())
                 {
-                    Fill(StreamKind, 0, ToFill.c_str(), ValueS);
+                    Fill(StreamKind, 0, ToFill.c_str(), ValueS, true);
                     if (ToFill=="FrameRate")
-                        Fill(StreamKind, 0, "FrameRate_Mode", "CFR");
+                        Fill(StreamKind, 0, "FrameRate_Mode", "CFR", Unlimited, true, true);
                 }
             }
             break;
@@ -1308,19 +1325,19 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
                 int8u Value;
                 Get_B1 (Value,                                  "Value");
                 std::string ToFill;
-                     if (StringData=="haskeyframes") {}
-                else if (StringData=="hasKeyframes") {}
-                else if (StringData=="hasVideo") {}
-                else if (StringData=="stereo") {}
-                else if (StringData=="canSeekToEnd") {}
-                else if (StringData=="hasAudio") {}
-                else if (StringData=="hasmetadata") {}
-                else if (StringData=="hasMetadata") {}
-                else if (StringData=="hasCuePoints") {}
-                else if (StringData=="canseekontime") {}
+                     if (StringDataModified=="haskeyframes") {}
+                else if (StringDataModified=="hasKeyframes") {}
+                else if (StringDataModified=="hasVideo") {}
+                else if (StringDataModified=="stereo") {}
+                else if (StringDataModified=="canSeekToEnd") {}
+                else if (StringDataModified=="hasAudio") {}
+                else if (StringDataModified=="hasmetadata") {}
+                else if (StringDataModified=="hasMetadata") {}
+                else if (StringDataModified=="hasCuePoints") {}
+                else if (StringDataModified=="canseekontime") {}
                 else {ToFill=StringData;}
-                Element_Info(Value);
-                Fill(Stream_General, 0, ToFill.c_str(), Value?"Yes":"No");
+                Element_Info1(Value);
+                Fill(Stream_General, 0, ToFill.c_str(), Value?"Yes":"No", Unlimited, true, true);
             }
             break;
         case 0x02 : //SCRIPTDATASTRING
@@ -1333,26 +1350,29 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
                     Get_UTF8(Value_Size, Value,                 "Value");
                     size_t ToFill=(size_t)-1;
                     std::string ToFillS;
-                         if (StringData=="creator") {ToFill=General_Encoded_Application;}
-                    else if (StringData=="creationdate") {ToFill=General_Encoded_Date; Value.Date_From_String(Value.To_UTF8().c_str());}
-                    else if (StringData=="encoder") {ToFill=General_Encoded_Application;}
-                    else if (StringData=="Encoded_With") {ToFill=General_Encoded_Application;}
-                    else if (StringData=="Encoded_By") {ToFill=General_Encoded_Application;}
-                    else if (StringData=="metadatacreator") {ToFill=General_Tagged_Application;}
-                    else if (StringData=="sourcedata") {}
-                    else if (StringData=="audiocodecid") {}
-                    else if (StringData=="videocodecid") {}
-                    else
+                         if (StringDataModified=="creator") {ToFill=General_Encoded_Application;}
+                    else if (StringDataModified=="creationdate") {ToFill=General_Encoded_Date; Value.Date_From_String(Value.To_UTF8().c_str());}
+                    else if (StringDataModified=="encoder") {ToFill=General_Encoded_Application;}
+                    else if (StringDataModified=="Encoded_With") {ToFill=General_Encoded_Application;}
+                    else if (StringDataModified=="Encoded_By") {ToFill=General_Encoded_Application;}
+                    else if (StringDataModified=="metadatacreator") {ToFill=General_Tagged_Application;}
+                    else if (StringDataModified=="creation_time") {ToFill=General_Encoded_Date; Value.insert(0, __T("UTC "));}
+                    else if (StringDataModified=="sourcedata") {}
+                    else if (StringDataModified=="audiocodecid") {}
+                    else if (StringDataModified=="videocodecid") {}
+                    else if (!(StringDataModified=="major_brand"
+                            || StringDataModified=="minor_version"
+                            || StringDataModified=="compatible_brands"))
                         ToFillS=StringData;
-                    if (Value.find(_T('\r'))!=std::string::npos)
-                        Value.resize(Value.find(_T('\r')));
-                    if (Value.find(_T('\n'))!=std::string::npos)
-                        Value.resize(Value.find(_T('\n')));
-                    Element_Info(Value);
+                    if (Value.find(__T('\r'))!=std::string::npos)
+                        Value.resize(Value.find(__T('\r')));
+                    if (Value.find(__T('\n'))!=std::string::npos)
+                        Value.resize(Value.find(__T('\n')));
+                    Element_Info1(Value);
                     if (ToFill!=(size_t)-1)
-                        Fill(Stream_General, 0, ToFill, Value);
+                        Fill(Stream_General, 0, ToFill, Value, true);
                     else if (!ToFillS.empty())
-                        Fill(Stream_General, 0, StringData.c_str(), Value);
+                        Fill(Stream_General, 0, StringData.c_str(), Value, true);
                 }
             }
             break;
@@ -1367,12 +1387,12 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
                 {
                     if (Element_Offset>=Element_Size)
                         break;
-                    Element_Begin();
+                    Element_Begin0();
                     Get_B2 (StringLength2,                          "StringLength2");
                     Get_String(StringLength2, StringData2,          "StringData2");
                     Element_Name(StringData2.empty()?"EndOfObject":StringData2.c_str());
                     meta_SCRIPTDATAVALUE(StringData+'_'+StringData2);
-                    Element_End();
+                    Element_End0();
                 }
                 meta_Level--;
             }
@@ -1385,9 +1405,9 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
                 {
                     Ztring Value;
                     Get_Local(Value_Size, Value,                "Value");
-                    if (Value==_T("unknown")) Value.clear();
-                    if (!Value.empty()) Element_Info(Value);
-                    Fill(Stream_General, 0, StringData.c_str(), Value);
+                    if (Value==__T("unknown")) Value.clear();
+                    Element_Info1C((!Value.empty()), Value);
+                    Fill(Stream_General, 0, StringData.c_str(), Value, true);
                 }
             }
             break;
@@ -1399,15 +1419,15 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
             {
                 int16u Value;
                 Get_B2 (Value,                                  "Value");
-                Element_Info(Value);
-                Fill(Stream_General, 0, StringData.c_str(), Value);
+                Element_Info1(Value);
+                Fill(Stream_General, 0, StringData.c_str(), Value, true);
             }
             break;
         case 0x08 : //SCRIPTDATAVARIABLE[ECMAArrayLength]
             {
                 int32u ECMAArrayLength;
                 Get_B4 (ECMAArrayLength,                        "ECMAArrayLength");
-                Element_Info(Ztring::ToZtring(ECMAArrayLength)+_T(" elements"));
+                Element_Info1(Ztring::ToZtring(ECMAArrayLength)+__T(" elements"));
                 for (int32u Pos=0; Pos<ECMAArrayLength; Pos++)
                 {
                     meta_SCRIPTDATAVARIABLE();
@@ -1417,7 +1437,7 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
             }
             break;
         case 0x09 :
-            Element_Info("EndOfObject");
+            Element_Info1("EndOfObject");
             meta_LevelFinished[meta_Level]=true;
             break;
         case 0x0A : //SCRIPTDATAVARIABLE[n]
@@ -1435,13 +1455,13 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
                 Get_BF8(Value,                                 "Value");
                 Ztring ValueS;
                 ValueS.Date_From_Seconds_1970((int32u)(Value/1000));
-                Param_Info(ValueS);
+                Param_Info1(ValueS);
                 Skip_B2(                                        "Local_Offset_Minutes");
                 std::string ToFill;
                      if (StringData=="metadatadate") {ToFill="Tagged_Date";}
                 else {ToFill=StringData;}
-                Element_Info(ValueS);
-                Fill(Stream_General, 0, ToFill.c_str(), ValueS);
+                Element_Info1(ValueS);
+                Fill(Stream_General, 0, ToFill.c_str(), ValueS, true);
             }
             break;
         case 0x0C : //SCRIPTDATALONGSTRING
@@ -1459,16 +1479,16 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
                     else if (StringData=="metadatacreator") {ToFill="Tagged_Application";}
                     else if (StringData=="creationdate") {ToFill="Encoded_Date"; Value.Date_From_String(Value.To_UTF8().c_str());}
                     else {ToFill=StringData;}
-                    Element_Info(Value);
+                    Element_Info1(Value);
                     if (!ToFill.empty())
-                        Fill(Stream_General, 0, ToFill.c_str(), Value);
+                        Fill(Stream_General, 0, ToFill.c_str(), Value, true);
                 }
             }
             break;
         case 0x11 : //AMF3 data
             {
                 int32u TypeCode;
-                Get_B4 (TypeCode,                               "AMF3 type code"); if (TypeCode<0x0D) Param_Info(Flv_Amf3Type[TypeCode]);
+                Get_B4 (TypeCode,                               "AMF3 type code"); Param_Info1C((TypeCode<0x0D), Flv_Amf3Type[TypeCode]);
                 switch (TypeCode)
                 {
                     case 0x00 : //undefined
