@@ -1,17 +1,17 @@
 // File_Mpegts - Info for MPEG Transport Stream files
-// Copyright (C) 2006-2011 MediaArea.net SARL, Info@MediaArea.net
+// Copyright (C) 2006-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // any later version.
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this library. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -103,6 +103,7 @@ private :
     //Elements
     void PSI();
     void PES();
+    void PES_Parse_Finish();
 
     //Helpers
     bool Header_Parser_QuickSearch();
@@ -133,6 +134,11 @@ private :
     void Streams_Update_EPG_PerProgram(complete_stream::transport_stream::programs::iterator Program);
     #ifdef MEDIAINFO_MPEGTS_PCR_YES
     void Streams_Update_Duration_Update();
+    #if MEDIAINFO_ADVANCED
+        float64 Config_VbrDetection_Delta;
+        int64u  Config_VbrDetection_Occurences;
+        bool    Config_VbrDetection_GiveUp;
+    #endif // MEDIAINFO_ADVANCED
     #endif //MEDIAINFO_MPEGTS_PCR_YES
     void Streams_Update_Duration_End();
 
@@ -153,14 +159,16 @@ private :
     bool TimeSection_FirstOccurrenceParsed;
 
     #if MEDIAINFO_SEEK
-        std::map<int16u, int64u> Unsynch_Frame_Counts;
+        std::map<int16u, int64u>    Unsynch_Frame_Counts;
+        int64u                      Seek_Value;
+        int64u                      Seek_Value_Maximal;
+        int64u                      Seek_ID;
+        size_t                      InfiniteLoop_Detect;
+        bool                        Duration_Detected;
     #endif //MEDIAINFO_SEEK
     #if MEDIAINFO_SEEK && MEDIAINFO_IBI
         ibi Ibi;
     #endif //MEDIAINFO_SEEK && MEDIAINFO_IBI
-    #if MEDIAINFO_IBI
-        File_Ibi_Creation IbiCreation;
-    #endif //MEDIAINFO_IBI
 };
 
 } //NameSpace
